<?php

	function oliver_font_subsets()
	{
		$font_subset    = "";
		$extra_char_set = false;
		
		if (get_theme_mod('oliver_setting_font_char_sets_latin', false)) { $font_subset .= 'latin,'; $extra_char_set = true; }
		if (get_theme_mod('oliver_setting_font_char_sets_latin_ext', false)) { $font_subset .= 'latin-ext,'; $extra_char_set = true; }
		if (get_theme_mod('oliver_setting_font_char_sets_cyrillic', false)) { $font_subset .= 'cyrillic,'; $extra_char_set = true; }
		if (get_theme_mod('oliver_setting_font_char_sets_cyrillic_ext', false)) { $font_subset .= 'cyrillic-ext,'; $extra_char_set = true; }
		if (get_theme_mod('oliver_setting_font_char_sets_greek', false)) { $font_subset .= 'greek,'; $extra_char_set = true; }
		if (get_theme_mod('oliver_setting_font_char_sets_greek_ext', false)) { $font_subset .= 'greek-ext,'; $extra_char_set = true; }
		if (get_theme_mod('oliver_setting_font_char_sets_vietnamese', false)) { $font_subset .= 'vietnamese,'; $extra_char_set = true; }
		
		if ($extra_char_set == false) { $font_subset = ""; } else { $font_subset = substr($font_subset, 0, -1); }
		
		return $font_subset;
	}
	
	
	function oliver_fonts_url($fonts = 'PT Mono|Comfortaa:300|Noto Sans:400,400italic,700,700italic|Arimo:400,400italic,700,700italic')
	{
		$font_url = "";
		$subsets  = oliver_font_subsets();
		
		/*
		 * Translators: If there are characters in your language that are not supported
		 * by chosen font(s), translate this to 'off'. Do not translate into your own language.
		 */
		
		if ('off' !== _x('on', 'Google font: on or off', 'oliver'))
		{
			$font_url = add_query_arg(
				array(
					'family' => urlencode($fonts),
					'subset' => urlencode($subsets)
				),
				'//fonts.googleapis.com/css'
			);
		}
		
		return $font_url;
	}
	
	
	function oliver_enqueue()
	{
		$theme_directory = get_template_directory_uri();
		
		wp_enqueue_style('oliver-fonts', oliver_fonts_url(), array(), null);
		wp_enqueue_style('normalize', $theme_directory . '/css/normalize.css', null, null);
		wp_enqueue_style('bootstrap', $theme_directory . '/css/bootstrap.css', null, null);
		wp_enqueue_style('fluidbox', $theme_directory . '/js/fluidbox/fluidbox.css', null, null);
		wp_enqueue_style('fontello', $theme_directory . '/css/fonts/fontello/css/fontello.css', null, null);
		wp_enqueue_style('magnific-popup', $theme_directory . '/js/jquery.magnific-popup/magnific-popup.css', null, null);
		wp_enqueue_style('owl-carousel', $theme_directory . '/js/owl-carousel/owl.carousel.css', null, null);
		wp_enqueue_style('oliver-main', $theme_directory . '/css/main.css', null, null);
		wp_enqueue_style('oliver-768', $theme_directory . '/css/768.css', null, null);
		wp_enqueue_style('oliver-992', $theme_directory . '/css/992.css', null, null);
		wp_enqueue_style('oliver-style', get_stylesheet_uri(), null, null);
		wp_enqueue_style('oliver-oliver', $theme_directory . '/css/oliver.css', null, null);
		
		
		if (is_singular() && comments_open() && get_option('thread_comments')) { wp_enqueue_script('comment-reply'); }
		
		$smooth_scroll = get_theme_mod('oliver_setting_smooth_scroll', 'no');
		
		if ($smooth_scroll == 'yes')
		{
			wp_enqueue_script('smooth-scroll', $theme_directory . '/js/smooth-scroll.js', array('jquery'), null, true);
		}
		
		wp_enqueue_script('fastclick', $theme_directory . '/js/fastclick.js', array('jquery'), null, true);
		wp_enqueue_script('fitvids', $theme_directory . '/js/jquery.fitvids.js', array('jquery'), null, true);
		wp_enqueue_script('sticky-kit', $theme_directory . '/js/jquery.sticky-kit.min.js', array('jquery'), null, true);
		wp_enqueue_script('jarallax', $theme_directory . '/js/jarallax.min.js', array('jquery'), null, true);
		wp_enqueue_script('jarallax-video', $theme_directory . '/js/jarallax-video.min.js', array('jquery'), null, true);
		wp_enqueue_script('fluidbox', $theme_directory . '/js/fluidbox/jquery.fluidbox.min.js', array('jquery'), null, true);
		wp_enqueue_script('validate', $theme_directory . '/js/jquery.validate.js', array('jquery'), null, true);
		wp_enqueue_script('isotope', $theme_directory . '/js/isotope.pkgd.min.js', array('jquery'), null, true);
		wp_enqueue_script('magnific-popup', $theme_directory . '/js/jquery.magnific-popup/jquery.magnific-popup.min.js', array('jquery'), null, true);
		wp_enqueue_script('owl-carousel', $theme_directory . '/js/owl-carousel/owl.carousel.min.js', array('jquery'), null, true);
		wp_enqueue_script('imagesloaded', null, null, null, true);
		wp_enqueue_script('collagePlus', $theme_directory . '/js/jquery.collagePlus.min.js', array('jquery'), null, true);
		wp_enqueue_script('fittext', $theme_directory . '/js/jquery.fittext.js', array('jquery'), null, true);
		wp_enqueue_script('flexverticalcenter', $theme_directory . '/js/jquery.flexverticalcenter.js', array('jquery'), null, true);
		wp_enqueue_script('socialstream', $theme_directory . '/js/socialstream.jquery.js', array('jquery'), null, true);
		wp_enqueue_script('oliver-main', $theme_directory . '/js/main.js', array('jquery'), null, true);
	}
	
	
	function oliver_after_setup_theme()
	{
		load_theme_textdomain('oliver', get_template_directory() . '/languages');
		add_action('wp_enqueue_scripts', 'oliver_enqueue');
		register_nav_menus(array('oliver_theme_menu_location' => esc_html__('Theme Navigation Menu', 'oliver')));
		
		add_editor_style('admin/editor-style.css');
		
		add_theme_support('post-formats', array('image', 'gallery', 'audio', 'video', 'quote', 'link', 'chat', 'status', 'aside'));
		add_theme_support('html5', array('comment-list', 'comment-form', 'search-form', 'gallery', 'caption'));
		add_theme_support('automatic-feed-links');
		add_theme_support('title-tag');
		add_theme_support('post-thumbnails', array('post', 'page'));
		
		add_theme_support('woocommerce');
		add_theme_support('wc-product-gallery-zoom');
		add_theme_support('wc-product-gallery-lightbox');
		add_theme_support('wc-product-gallery-slider');
		
		add_theme_support(
			'custom-logo',
			array(
				'width'       => 800,
				'height'      => 300,
				'flex-width'  => true,
				'flex-height' => true
			)
		);
		
		remove_theme_support('widgets-block-editor');
	}
	
	add_action('after_setup_theme', 'oliver_after_setup_theme');
	
	
	function oliver_enqueue_admin()
	{
		$theme_directory = get_template_directory_uri();
		wp_enqueue_style('oliver-admin', $theme_directory . '/admin/admin.css', null, null);
		wp_enqueue_script('oliver-admin', $theme_directory . '/admin/admin.js', array('jquery'), null, true);
		wp_enqueue_media();
	}
	
	add_action('admin_enqueue_scripts', 'oliver_enqueue_admin');


/* ============================================================================================================================================= */


	function oliver_customize_controls()
	{
		$theme_directory = get_template_directory_uri();
		wp_enqueue_style('oliver-customize-controls', $theme_directory . '/admin/customize-controls.css', null, null);
	}
	
	add_action('customize_controls_enqueue_scripts', 'oliver_customize_controls');
	
	
	function oliver_customize_preview()
	{
		wp_enqueue_script('oliver-customize-preview', get_template_directory_uri() . '/admin/customize-preview.js', array('customize-preview'), null, true);
	}
	
	add_action('customize_preview_init', 'oliver_customize_preview');


/* ============================================================================================================================================= */


	function oliver_tiny_mce_before_init($init_array)
	{
		$formats = array(
			array(  
				'title'    => esc_html__('Link to Button', 'oliver'),
				'selector' => 'a',
				'classes'  => 'button'
			)
		);  
		
		$init_array['style_formats'] = json_encode($formats);
		
		return $init_array;
	}
	
	add_filter('tiny_mce_before_init', 'oliver_tiny_mce_before_init');
	
	
	function oliver_mce_buttons($buttons)
	{
		array_unshift(
			$buttons,
			'styleselect'
		);
		
		return $buttons;
	}
	
	add_filter('mce_buttons', 'oliver_mce_buttons');


/* ============================================================================================================================================= */


	remove_action('woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5);
	
	
	function oliver_remove_wc_breadcrumbs()
	{
		remove_action('woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0);
	}
	
	add_action('init', 'oliver_remove_wc_breadcrumbs');
	
	
	function oliver_header_add_to_cart_fragment($fragments)
	{
		ob_start();
		$count = WC()->cart->cart_contents_count;
		
		?>
			<a class="shopping-cart" href="<?php echo esc_url(wc_get_cart_url()); ?>" title="<?php esc_html_e('View your shopping cart', 'oliver'); ?>">
				<?php
					if ($count > 0)
					{
						?>
							<span>
								<?php
									echo esc_html($count);
								?>
							</span>
						<?php            
					}
				?>
			</a>
		<?php
		
		$fragments['a.shopping-cart'] = ob_get_clean();
		
		return $fragments;
	}
	
	add_filter('woocommerce_add_to_cart_fragments', 'oliver_header_add_to_cart_fragment');
	
	
	function oliver_wc_cart_count()
	{
		if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins'))))
		{
			$count = WC()->cart->cart_contents_count;
			
			?>
				<a class="shopping-cart" href="<?php echo esc_url(wc_get_cart_url()); ?>" title="<?php esc_html_e('View your shopping cart', 'oliver'); ?>">
					<?php
						if ($count > 0)
						{
							?>
								<span>
									<?php
										echo esc_html($count);
									?>
								</span>
							<?php
						}
					?>
				</a>
			<?php
		}
	}
	
	add_action('oliver_header_cart_icon', 'oliver_wc_cart_count');
	
	
	// $cols contains the current number of products per page based on the value stored on Options -> Reading.
	// Return the number of products you wanna show per page.
	
	function oliver_loop_shop_per_page($cols)
	{
		$posts_per_page = get_theme_mod('oliver_setting_products_per_page', '9');
		
		if (! empty($posts_per_page))
		{
			$posts_per_page = intval($posts_per_page);
		}
		else
		{
			$posts_per_page = 8;
		}
		
		$cols = $posts_per_page;
		
		return $cols;
	}
	
	add_filter('loop_shop_per_page', 'oliver_loop_shop_per_page', 20);
	
	
	/**
	 * WooCommerce Extra Feature
	 * --------------------------
	 *
	 * Change number of related products on product page.
	 * Set your own value for 'posts_per_page'.
	 *
	 */
	
	function woo_related_products_limit()
	{
		global $product;
		
		$args['posts_per_page'] = 6;
		
		return $args;
	}
	
	
	function oliver_related_products_args($args)
	{
		$posts_per_page = get_theme_mod('oliver_setting_related_products_count', '3');
		
		if (! empty($posts_per_page))
		{
			$posts_per_page = intval($posts_per_page);
		}
		else
		{
			$posts_per_page = 3;
		}
		
		$args['posts_per_page'] = $posts_per_page; // Related products.
		$args['columns'] = 3; // Arranged in 3 columns.
		
		return $args;
	}
	
	add_filter('woocommerce_output_related_products_args', 'oliver_related_products_args');


/* ============================================================================================================================================= */


	add_image_size('oliver_image_size_1', 1060); // blog-regular, single-post, 1st-full, gallery-type-slider, gallery-type-grid, main-slider-50%, main-slider-100%, page-default, page-medium
	add_image_size('oliver_image_size_2', 550); // blog-grid-masonry, blog-list, about-me-widget, woocommerce-shop-page, portfolio-page-feat-img
	add_image_size('oliver_image_size_3', 550, 550, true); // blog-circles, related-posts, main-slider-50%, main-slider-75%, link-box-widget, intro-widget, portfolio-page-feat-img
	add_image_size('oliver_image_size_4', 550, 362, true); // blog-grid-fitRows, portfolio-page-feat-img
	add_image_size('oliver_image_size_5', 300, 300, true); // prev-post, next-post, page_template-latest_posts
	add_image_size('oliver_image_size_6', null, 500); // gallery-type-grid
	add_image_size('oliver_image_size_7', 1920); // magnific-popup-width, gallery-type-slider, main-slider-75%, main-slider-100%, intro-widget bg img, page-full, single-post, (single-portfolio-format --> link, image)
	add_image_size('oliver_image_size_8', null, 1080); // magnific-popup-height


/* ============================================================================================================================================= */


	if (! isset($content_width))
	{
		$content_width = 700;
		
		// All below values are depending on default Main Style. (Default v2)
		
		if (is_page_template('page_template-full.php'))
		{
			// Flexible.
		}
		elseif (is_page_template('page_template-medium.php'))
		{
			$content_width = 1060;
		}
		elseif (is_page_template('page_template-latest_posts.php'))
		{
			$content_width = 740;
		}
		elseif (is_page_template('page_template-portfolio.php'))
		{
			$content_width = 1060;
		}
		elseif (is_page())
		{
			$content_width = 740;
		}
		elseif (is_singular('portfolio'))
		{
			$content_width = 740;
		}
		elseif (is_single())
		{
			$content_width = 710;
		}
		else
		{
			$content_width = 710;
		}
	}


/* ============================================================================================================================================= */


	/*
		To override this walker in a child theme without modifying the comments template
		simply create your own oliver_theme_comments(), and that function will be used instead.
		
		Used as a callback by wp_list_comments() for displaying the comments.
	*/
	
	function oliver_theme_comments($comment, $args, $depth)
	{
		$GLOBALS['comment'] = $comment;
		
		switch ($comment->comment_type)
		{
			case 'pingback' :
			
			case 'trackback' :
			
				?>
					<li id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
						<p>
							<?php
								esc_html_e('Pingback:', 'oliver');
							?>
							<?php
								comment_author_link();
							?>
							<?php
								edit_comment_link(esc_html__('(Edit)', 'oliver'), '<span class="edit-link">', '</span>');
							?>
						</p>
				<?php
			
			break;
			
			default :
			
				global $post;
				
				?>
					<li id="li-comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
						<article id="comment-<?php comment_ID(); ?>" class="comment">
							<header class="comment-meta comment-author vcard">
								<?php
									echo get_avatar($comment, 150);
								?>
								<cite class="fn">
									<?php
										echo get_comment_author_link();
									?>
								</cite>
								<span class="comment-date">
									<?php
										echo get_comment_date();
									?>
									<?php
										esc_html_e('at', 'oliver');
									?>
									<?php
										echo get_comment_time();
									?>
									<?php
										edit_comment_link(esc_html__('Edit', 'oliver'), '<span class="comment-edit-link">', '</span>');
									?>
								</span>
							</header>
							
							<section class="comment-content comment">
								<?php
									if ('0' == $comment->comment_approved)
									{
										?>
											<p class="comment-awaiting-moderation">
												<?php
													esc_html_e('Your comment is awaiting moderation.', 'oliver');
												?>
											</p>
										<?php
									}
								?>
								<?php
									comment_text();
								?>
							</section>
							
							<div class="reply">
								<?php
									comment_reply_link(array_merge($args,
																   array('reply_text' => esc_html__('Reply', 'oliver'),
																		 'after'      => ' <span>&#8595;</span>',
																		 'depth'      => $depth,
																		 'max_depth'  => $args['max_depth'])));
								?>
							</div>
						</article>
				<?php
			
			break;
		}
	}


/* ============================================================================================================================================= */


	register_sidebar( array('name'          => esc_html__('Blog Sidebar', 'oliver'),
							'id'            => 'oliver_sidebar_1',
							'description'   => esc_html__('Add widgets.', 'oliver'),
							'before_widget' => '<aside id="%1$s" class="widget %2$s">',
							'after_widget'  => '</aside>',
							'before_title'  => '<h3 class="widget-title"><span>',
							'after_title'   => '</span></h3>'));
	
	register_sidebar( array('name'          => esc_html__('Post Sidebar', 'oliver'),
							'id'            => 'oliver_sidebar_2',
							'description'   => esc_html__('Add widgets.', 'oliver'),
							'before_widget' => '<aside id="%1$s" class="widget %2$s">',
							'after_widget'  => '</aside>',
							'before_title'  => '<h3 class="widget-title"><span>',
							'after_title'   => '</span></h3>'));
	
	register_sidebar( array('name'          => esc_html__('Page Sidebar', 'oliver'),
							'id'            => 'oliver_sidebar_3',
							'description'   => esc_html__('- Add widgets. - Select this sidebar in edit screen of a page to display it with this sidebar.', 'oliver'),
							'before_widget' => '<aside id="%1$s" class="widget %2$s">',
							'after_widget'  => '</aside>',
							'before_title'  => '<h3 class="widget-title"><span>',
							'after_title'   => '</span></h3>'));
	
	register_sidebar( array('name'          => esc_html__('Portfolio Sidebar', 'oliver'),
							'id'            => 'oliver_sidebar_15',
							'description'   => esc_html__('Select this sidebar in edit screen of your portfolio page. Also this sidebar can be used for portfolio categories and portfolio posts when activated from Customizer.', 'oliver'),
							'before_widget' => '<aside id="%1$s" class="widget %2$s">',
							'after_widget'  => '</aside>',
							'before_title'  => '<h3 class="widget-title"><span>',
							'after_title'   => '</span></h3>'));
	
	register_sidebar( array('name'          => esc_html__('Shop Sidebar', 'oliver'),
							'id'            => 'oliver_sidebar_16',
							'description'   => esc_html__('- Add widgets. - Enable this sidebar for shop page, shop category page and single product page from Customizer > Sidebar.', 'oliver'),
							'before_widget' => '<aside id="%1$s" class="widget %2$s">',
							'after_widget'  => '</aside>',
							'before_title'  => '<h3 class="widget-title"><span>',
							'after_title'   => '</span></h3>'));
	
	register_sidebar( array('name'          => esc_html__('Blog Featured Area', 'oliver'),
							'id'            => 'oliver_sidebar_13',
							'description'   => esc_html__('Add Main Slider/Link Box/Intro widgets.', 'oliver'),
							'before_widget' => "",
							'after_widget'  => "",
							'before_title'  => '<span style="display: none;">',
							'after_title'   => '</span>'));
	
	register_sidebar( array('name'          => esc_html__('Page Featured Area', 'oliver'),
							'id'            => 'oliver_sidebar_14',
							'description'   => esc_html__('Add Main Slider/Link Box/Intro widgets.', 'oliver'),
							'before_widget' => "",
							'after_widget'  => "",
							'before_title'  => '<span style="display: none;">',
							'after_title'   => '</span>'));
	
	register_sidebar( array('name'          => esc_html__('Portfolio Featured Area', 'oliver'),
							'id'            => 'oliver_sidebar_17',
							'description'   => esc_html__('Add Main Slider/Link Box/Intro widgets.', 'oliver'),
							'before_widget' => "",
							'after_widget'  => "",
							'before_title'  => '<span style="display: none;">',
							'after_title'   => '</span>'));
	
	register_sidebar( array('name'          => esc_html__('Shop Featured Area', 'oliver'),
							'id'            => 'oliver_sidebar_18',
							'description'   => esc_html__('Add Main Slider/Link Box/Intro widgets.', 'oliver'),
							'before_widget' => "",
							'after_widget'  => "",
							'before_title'  => '<span style="display: none;">',
							'after_title'   => '</span>'));
	
	register_sidebar( array('name'          => esc_html__('Header Social Media Icons', 'oliver'),
							'id'            => 'oliver_sidebar_4',
							'description'   => esc_html__('Add Social Media Icon widget per icon.', 'oliver'),
							'before_widget' => "",
							'after_widget'  => "",
							'before_title'  => '<span style="display: none;">',
							'after_title'   => '</span>'));
	
	register_sidebar( array('name'          => esc_html__('Author Social Media Icons', 'oliver'),
							'id'            => 'oliver_sidebar_8',
							'description'   => esc_html__('Add Social Media Icon widget per icon.', 'oliver'),
							'before_widget' => "",
							'after_widget'  => "",
							'before_title'  => '<span style="display: none;">',
							'after_title'   => '</span>'));
	
	register_sidebar( array('name'          => esc_html__('Footer Subscribe', 'oliver'),
							'id'            => 'oliver_sidebar_5',
							'description'   => esc_html__('Add widget.', 'oliver'),
							'before_widget' => "",
							'after_widget'  => "",
							'before_title'  => '<h3>',
							'after_title'   => '</h3>'));
	
	register_sidebar( array('name'          => esc_html__('Footer Instagram', 'oliver'),
							'id'            => 'oliver_sidebar_6',
							'description'   => esc_html__('Add widget.', 'oliver'),
							'before_widget' => "",
							'after_widget'  => "",
							'before_title'  => '<span style="display: none;">',
							'after_title'   => '</span>'));
	
	register_sidebar( array('name'          => esc_html__('Footer 1', 'oliver'),
							'id'            => 'oliver_sidebar_9',
							'description'   => esc_html__('Add widgets.', 'oliver'),
							'before_widget' => '<aside id="%1$s" class="widget %2$s">',
							'after_widget'  => '</aside>',
							'before_title'  => '<h3 class="widget-title"><span>',
							'after_title'   => '</span></h3>'));
	
	register_sidebar( array('name'          => esc_html__('Footer 2', 'oliver'),
							'id'            => 'oliver_sidebar_10',
							'description'   => esc_html__('Add widgets.', 'oliver'),
							'before_widget' => '<aside id="%1$s" class="widget %2$s">',
							'after_widget'  => '</aside>',
							'before_title'  => '<h3 class="widget-title"><span>',
							'after_title'   => '</span></h3>'));
	
	register_sidebar( array('name'          => esc_html__('Footer 3', 'oliver'),
							'id'            => 'oliver_sidebar_11',
							'description'   => esc_html__('Add widgets.', 'oliver'),
							'before_widget' => '<aside id="%1$s" class="widget %2$s">',
							'after_widget'  => '</aside>',
							'before_title'  => '<h3 class="widget-title"><span>',
							'after_title'   => '</span></h3>'));
	
	register_sidebar( array('name'          => esc_html__('Footer 4', 'oliver'),
							'id'            => 'oliver_sidebar_12',
							'description'   => esc_html__('Add widgets.', 'oliver'),
							'before_widget' => '<aside id="%1$s" class="widget %2$s">',
							'after_widget'  => '</aside>',
							'before_title'  => '<h3 class="widget-title"><span>',
							'after_title'   => '</span></h3>'));
	
	register_sidebar( array('name'          => esc_html__('Footer Copyright Text', 'oliver'),
							'id'            => 'oliver_sidebar_7',
							'description'   => esc_html__('Add Text widget.', 'oliver'),
							'before_widget' => "",
							'after_widget'  => "",
							'before_title'  => '<span style="display: none;">',
							'after_title'   => '</span>'));
	
	$oliver_sidebars_with_commas = get_option('oliver_sidebars_with_commas');
	
	if ($oliver_sidebars_with_commas != "")
	{
		$sidebars = preg_split("/[\s]*[,][\s]*/", $oliver_sidebars_with_commas);
		
		foreach ($sidebars as $sidebar_name)
		{
			register_sidebar( array('name'          => $sidebar_name,
									'id'            => $sidebar_name,
									'description'   => esc_html__('Add widgets.', 'oliver'),
									'before_widget' => '<aside id="%1$s" class="widget %2$s">',
									'after_widget'  => '</aside>',
									'before_title'  => '<h3 class="widget-title"><span>',
									'after_title'   => '</span></h3>'));
		}
	}


/* ============================================================================================================================================= */


	function oliver_post_column_add($columns)
	{
		return array_merge($columns,
						   array('oliver_post_feat_img' => esc_html__('Featured Image', 'oliver')));
	}
	
	add_filter('manage_posts_columns', 'oliver_post_column_add');
	
	
	function oliver_post_column_show($column, $post_id)
	{
		if ($column == 'oliver_post_feat_img')
		{
			the_post_thumbnail(
				'thumbnail',
				array(
					'style' => 'max-height: 40px; max-width: 40px;'
				)
			);
		}
	}
	
	add_action('manage_posts_custom_column' , 'oliver_post_column_show', 10, 2);


/* ============================================================================================================================================= */


	function oliver_pre_get_posts($query)
	{
		$sticky_posts = get_theme_mod('oliver_setting_sticky_posts', 'exclude');
		
		if (($sticky_posts != 'include') && ($query->is_main_query()) && is_home() && (! is_admin()))
		{
			$query->set('post__not_in', get_option('sticky_posts'));
		}
	}
	
	add_action('pre_get_posts', 'oliver_pre_get_posts');


/* ============================================================================================================================================= */


	function oliver_featured_area()
	{
		if ((! isset($_GET['featured_area'])) && is_home() && is_active_sidebar('oliver_sidebar_13'))
		{
			?>
				<section class="top-content">
					<div class="layout-medium">
						<div class="featured-area">
							<?php
								dynamic_sidebar('oliver_sidebar_13');
							?>
						</div>
					</div>
				</section>
			<?php
		}
	}


/* ============================================================================================================================================= */


	function oliver_sidebar_yes_no()
	{
		global $oliver_sidebar;
		$oliver_sidebar = 'with-sidebar';
		
		if (isset($_GET['sidebar']))
		{
			if ($_GET['sidebar'] == 'no')
			{
				$oliver_sidebar = "";
			}
		}
		else
		{
			if (! have_posts())
			{
				$oliver_sidebar = "";
			}
			elseif (is_singular('portfolio'))
			{
				$sidebar_portfolio_post = get_theme_mod('oliver_setting_sidebar_portfolio_post', 'No');
				
				if ($sidebar_portfolio_post != 'Yes')
				{
					$oliver_sidebar = "";
				}
			}
			elseif (is_single())
			{
				$sidebar_post = get_theme_mod('oliver_setting_sidebar_post', 'No');
				
				if ($sidebar_post != 'Yes')
				{
					$oliver_sidebar = "";
				}
			}
			else
			{
				$sidebar_blog = get_theme_mod('oliver_setting_sidebar_blog', 'No');
				
				if ($sidebar_blog != 'Yes')
				{
					$oliver_sidebar = "";
				}
			}
		}
	}


/* ============================================================================================================================================= */


	function oliver_sidebar()
	{
		if (! is_404())
		{
			?>
				<div id="secondary" class="widget-area sidebar" role="complementary">
				    <div class="sidebar-wrap">
						<div class="sidebar-content">
							<?php
								if (is_page())
								{
									$select_page_sidebar = get_option('oliver_select_page_sidebar' . '__' . get_the_ID(), 'No Sidebar');
									dynamic_sidebar($select_page_sidebar); // Page sidebar. (for default and custom page templates)
								}
								elseif (is_post_type_archive('product') || is_tax('product_cat') || is_singular('product'))
								{
									dynamic_sidebar('oliver_sidebar_16'); // Shop sidebar. (WooCommerce)
								}
								elseif (is_tax('portfolio-category') || is_singular('portfolio'))
								{
									dynamic_sidebar('oliver_sidebar_15'); // Portfolio sidebar.
								}
								elseif (is_singular('post'))
								{
									if (is_active_sidebar('oliver_sidebar_2'))
									{
										dynamic_sidebar('oliver_sidebar_2'); // Post sidebar.
									}
									else
									{
										dynamic_sidebar('oliver_sidebar_1'); // Blog sidebar.
									}
								}
								else
								{
									dynamic_sidebar('oliver_sidebar_1'); // Blog sidebar.
								}
							?>
						</div> <!-- .sidebar-content -->
					</div> <!-- .sidebar-wrap -->
				</div> <!-- #secondary .widget-area .sidebar -->
			<?php
		}
	}


/* ============================================================================================================================================= */


	function oliver_excerpt_length($length)
	{
		$layout = 'Regular';
		
		if (isset($_GET['layout']))
		{
			$layout = $_GET['layout'];
		}
		else
		{
			if (is_category())
			{
				$layout = get_theme_mod('oliver_setting_layout_category', 'Grid');
			}
			elseif (is_tag())
			{
				$layout = get_theme_mod('oliver_setting_layout_tag', 'Grid');
			}
			elseif (is_author())
			{
				$layout = get_theme_mod('oliver_setting_layout_author', 'Grid');
			}
			elseif (is_date())
			{
				$layout = get_theme_mod('oliver_setting_layout_date', 'Grid');
			}
			elseif (is_search())
			{
				$layout = get_theme_mod('oliver_setting_layout_search', 'Grid');
			}
			else
			{
				$layout = get_theme_mod('oliver_setting_layout_blog', 'Regular');
			}
		}
		
		if (($layout == 'Regular') || ($layout == 'regular'))
		{
			return get_theme_mod('oliver_setting_excerpt_length', '65');
		}
		else
		{
			return get_theme_mod('oliver_setting_excerpt_length_layout_grid', '35');
		}
	}
	
	add_filter('excerpt_length', 'oliver_excerpt_length', 999);
	
	
	function oliver_read_more_link()
	{
		return '<p class="more"><a class="more-link" href="' . esc_url(get_permalink()) . '">' . esc_html__('Read More', 'oliver') . '</a></p>';
	}
	
	add_filter('the_content_more_link', 'oliver_read_more_link');
	
	
	function oliver_excerpt_more($more)
	{
		return '... ' . oliver_read_more_link();
	}
	
	add_filter('excerpt_more', 'oliver_excerpt_more');
	
	
	function oliver_content()
	{
		if (is_home() || is_archive() || is_search())
		{
			if (has_excerpt())
			{
				the_excerpt();
				
				echo oliver_read_more_link();
			}
			else
			{
				$automatic_excerpt = get_theme_mod('oliver_setting_automatic_excerpt', 'standard');
				
				if (isset($_GET['layout']))
				{
					if ($_GET['layout'] != 'regular')
					{
						$automatic_excerpt = 'Yes';
					}
				}
				else
				{
					$layout = "";
					
					if (is_category())
					{
						$layout = get_theme_mod('oliver_setting_layout_category', 'Grid');
					}
					elseif (is_tag())
					{
						$layout = get_theme_mod('oliver_setting_layout_tag', 'Grid');
					}
					elseif (is_author())
					{
						$layout = get_theme_mod('oliver_setting_layout_author', 'Grid');
					}
					elseif (is_date())
					{
						$layout = get_theme_mod('oliver_setting_layout_date', 'Grid');
					}
					elseif (is_search())
					{
						$layout = get_theme_mod('oliver_setting_layout_search', 'Grid');
					}
					else
					{
						$layout = get_theme_mod('oliver_setting_layout_blog', 'Regular');
					}
					
					if ($layout != 'Regular')
					{
						$automatic_excerpt = 'Yes';
					}
				}
				
				if ($automatic_excerpt == 'Yes')
				{
					the_excerpt();
				}
				elseif ($automatic_excerpt == 'standard')
				{
					$format = get_post_format();
					
					if ($format == false)
					{
						the_excerpt();
					}
					else
					{
						the_content();
					}
				}
				else
				{
					the_content();
				}
			}
		}
		else
		{
			the_content();
		}
		
		wp_link_pages(array('before'      => '<div class="page-links"><span class="page-links-title">' . esc_html__('Pages:', 'oliver') . '</span>',
							'after'       => '</div>',
							'link_before' => '<span class="page-number">',
							'link_after'  => '</span>' ));
	}


/* ============================================================================================================================================= */


	function oliver_archive_title()
	{
		if (! is_front_page())
		{
			?>
				<div class="post-header archive-header post-header-classic">
					<?php
						if (is_category())
						{
							?>
								<header class="entry-header">
									<h1 class="entry-title">
										<i><?php esc_html_e('Browsing Category', 'oliver'); ?></i>
										
										<span class="cat-title"><?php echo single_cat_title(); ?></span>
									</h1>
									<?php
										if (category_description())
										{
											?>
												<div class="category-description">
													<?php
														echo category_description();
													?>
												</div> <!-- .category-description -->
											<?php
										}
									?>
								</header> <!-- .entry-header -->
							<?php
						}
						elseif (is_tag())
						{
							?>
								<header class="entry-header">
									<h1 class="entry-title">
										<i><?php esc_html_e('Posts tagged', 'oliver'); ?></i>
										
										<span class="cat-title"><?php echo single_tag_title(); ?></span>
									</h1>
								</header> <!-- .entry-header -->
							<?php
						}
						elseif (is_author())
						{
							?>
								<header class="entry-header">
									<h1 class="entry-title">
										<i><?php esc_html_e('Posts Published by', 'oliver'); ?></i>
										
										<span class="cat-title"><?php the_author(); ?></span>
									</h1>
								</header> <!-- .entry-header -->
							<?php
						}
						elseif (is_search())
						{
							?>
								<header class="entry-header">
									<h1 class="entry-title">
										<i><?php esc_html_e('you searched for', 'oliver'); ?></i>
										
										<span class="cat-title"><?php the_search_query(); ?></span>
									</h1>
								</header> <!-- .entry-header -->
							<?php
						}
						elseif (is_date())
						{
							?>
								<header class="entry-header">
									<h1 class="entry-title">
										<i><?php esc_html_e('Date Archives', 'oliver'); ?></i>
										
										<span class="cat-title">
											<?php
												if (is_day())
												{
													printf(get_the_date());
												}
												elseif (is_month())
												{
													printf(get_the_date(_x('F Y', 'monthly archives date format', 'oliver')));
												}
												elseif (is_year())
												{
													printf(get_the_date(_x('Y', 'yearly archives date format', 'oliver')));
												}
												else
												{
													esc_html_e('Archives', 'oliver');
												}
											?>
										</span>
									</h1>
								</header> <!-- .entry-header -->
							<?php
						}
						elseif (is_post_type_archive())
						{
							?>
								<header class="entry-header">
									<h1 class="entry-title">
										<i><?php esc_html_e('Archives', 'oliver'); ?></i>
										
										<span class="cat-title"><?php echo post_type_archive_title(); ?></span>
									</h1>
								</header> <!-- .entry-header -->
							<?php
						}
						elseif (is_archive())
						{
							?>
								<header class="entry-header">
									<h1 class="entry-title">
										<i><?php esc_html_e('Archives', 'oliver'); ?></i>
										
										<span class="cat-title"><?php echo single_term_title(); ?></span>
									</h1>
								</header> <!-- .entry-header -->
							<?php
						}
						else
						{
							$oliver_title_visibility = false;
							$blog_page_id = get_option('page_for_posts');
							
							if ($blog_page_id)
							{
								$oliver_title_visibility = get_option($blog_page_id . 'oliver_title_visibility', false);
							}
							
							?>
								<header class="entry-header" <?php if ($oliver_title_visibility == true) { echo 'style="display: none;"'; } ?>>
									<h1 class="entry-title">
										<?php
											single_post_title();
										?>
									</h1>
								</header> <!-- .entry-header -->
							<?php
						}
					?>
				</div> <!-- .post-header-classic -->
			<?php
		}
	}


/* ============================================================================================================================================= */


	function oliver_post_tags()
	{
		$tags = get_theme_mod('oliver_setting_tags', 'Yes');
		
		if ($tags != 'No')
		{
			if (get_the_tags() != "")
			{
				?>
					<div class="post-tags tagcloud">
						<?php
							the_tags("", ' ', "");
						?>
					</div>
				<?php
			}
		}
	}


/* ============================================================================================================================================= */


	function oliver_about_author()
	{
		$oliver_about_the_author_module = get_theme_mod('oliver_setting_author_info_box', 'Yes');
		
		if (($oliver_about_the_author_module != 'No') && (is_singular('post')))
		{
			?>
				<aside class="about-author">
					<h3 class="widget-title">
						<span>
							<?php
								esc_html_e('Written By', 'oliver');
							?>
						</span>
					</h3>
					
					<div class="author-bio">
						<div class="author-img">
							<a href="<?php echo get_author_posts_url(get_the_author_meta('ID')); ?>">
								<?php
									echo get_avatar(get_the_author_meta('user_email'), 300, "", get_the_author_meta('display_name'));
								?>
							</a>
						</div>
						<div class="author-info">
							<h4 class="author-name">
								<?php
									the_author();
								?>
							</h4>
							<p>
								<?php	
									echo get_the_author_meta('description');
								?>
							</p>
							<?php
								dynamic_sidebar('oliver_sidebar_8');
							?>
						</div>
					</div>
				</aside>
			<?php
		}
	}


/* ============================================================================================================================================= */


	function oliver_related_posts_style__overlay($query)
	{
		if ($query->have_posts()) :
			?>
				<div class="related-posts">
					<h3 class="widget-title">
						<span>
							<?php
								esc_html_e('You May Also Like', 'oliver');
							?>
						</span>
					</h3>
					<div class="blocks">
						<?php
							while ($query->have_posts()) : $query->the_post();
							
								$feat_img = wp_get_attachment_image_src(get_post_thumbnail_id(), 'oliver_image_size_3');
								
								?>
									<div class="block">
										<div class="post-thumbnail" style="background-image: url(<?php echo esc_url($feat_img[0]); ?>);">
											<div class="post-wrap">
												<header class="entry-header">
													<div class="entry-meta">
														<span class="cat-links">
															<?php
																the_category(' ');
															?>
														</span>
													</div>
													<h2 class="entry-title">
														<a href="<?php the_permalink(); ?>">
															<?php
																the_title();
															?>
														</a>
													</h2>
													<a class="more-link" href="<?php the_permalink(); ?>">
														<?php
															esc_html_e('View Post', 'oliver');
														?>
													</a>
												</header>
											</div>
										</div>
									</div>
								<?php
							endwhile;
						?>
					</div>
				</div>
			<?php
		endif;
		wp_reset_postdata();
	}
	
	
	function oliver_related_posts_style__classic($query)
	{
		if ($query->have_posts()) :
			?>
				<div class="related-posts">
					<h3 class="widget-title">
						<span>
							<?php
								esc_html_e('You May Also Like', 'oliver');
							?>
						</span>
					</h3>
					<div class="blocks">
						<?php
							while ($query->have_posts()) : $query->the_post();
								?>
									<div class="block">
										<div class="related-post post-classic">
											<?php
												if (has_post_thumbnail())
												{
													?>
														<div class="featured-image">
															<a href="<?php the_permalink(); ?>">
																<?php
																	the_post_thumbnail('oliver_image_size_3');
																?>
															</a>
														</div>
													<?php
												}
											?>
											<header class="entry-header">
												<div class="entry-meta">
													<span class="posted-on">
														<span class="prefix">
															<?php
																esc_html_e('on', 'oliver');
															?>
														</span>
														<a href="<?php the_permalink(); ?>" rel="bookmark">
															<time class="entry-date published" datetime="<?php echo get_the_date('c'); ?>">
																<?php
																	echo get_the_date();
																?>
															</time>
														</a>
													</span>
												</div>
												<h2 class="entry-title">
													<a href="<?php the_permalink(); ?>">
														<?php
															the_title();
														?>
													</a>
												</h2>
											</header>
										</div>
									</div>
								<?php
							endwhile;
						?>
					</div>
				</div>
			<?php
		endif;
		wp_reset_postdata();
	}
	
	
	function oliver_related_posts_style($query)
	{
		$related_posts_style = get_theme_mod('oliver_setting_related_posts_style', 'classic');
		
		if ($related_posts_style == 'overlay')
		{
			oliver_related_posts_style__overlay($query);
		}
		else
		{
			oliver_related_posts_style__classic($query);
		}
	}
	
	
	function oliver_related_posts_html()
	{
		$category_ids = "";
		$categories   = get_the_category();
		
		if ($categories)
		{
			foreach ($categories as $category)
			{
				$category_ids .= $category->cat_ID . ',';
			}
			
			$category_ids = trim($category_ids, ',');
		}
		
		$exclude_ids = array(get_the_ID());
		
		$query = new WP_Query(array('post_type'      => 'post',
									'cat'            => $category_ids,
									'post__not_in'   => $exclude_ids,
									'posts_per_page' => 3));
		
		oliver_related_posts_style($query);
	}
	
	
	function oliver_related_posts()
	{
		$related_posts = get_theme_mod('oliver_setting_related_posts', 'Yes');
		
		if (($related_posts != 'No') && (! is_attachment()))
		{
			oliver_related_posts_html();
		}
	}


/* ============================================================================================================================================= */


	function oliver_blog_navigation()
	{
		$numbered_pagination = get_theme_mod('oliver_setting_numbered_pagination', 'No');
		
		if ($numbered_pagination == 'Yes')
		{
			the_posts_pagination(array('screen_reader_text' => esc_html__('Posts navigation', 'oliver'),
									   'prev_text'          => esc_html__('Prev', 'oliver'),
									   'next_text'          => esc_html__('Next', 'oliver'),
									   'end_size' 			=> 1,
									   'mid_size' 			=> 1,
									   'before_page_number' => '<span class="meta-nav screen-reader-text">' . esc_html__('Page', 'oliver') . ' </span>'));
		}
		else
		{
			$next_posts_link     = get_next_posts_link();
			$previous_posts_link = get_previous_posts_link();
			
			if (($next_posts_link != "") || ($previous_posts_link != ""))
			{
				?>
					<nav class="navigation" role="navigation">
						<div class="nav-previous">
							<?php
								next_posts_link('&#8592; ' . esc_html__('Older Posts', 'oliver'));
							?>
						</div> <!-- .nav-previous -->
						<div class="nav-next">
							<?php
								previous_posts_link(esc_html__('Newer Posts', 'oliver') . ' &#8594;');
							?>
						</div> <!-- .nav-next -->
					</nav> <!-- .navigation -->
				<?php
			}
		}
	}


/* ============================================================================================================================================= */


	if (! function_exists('oliver_single_navigation_html'))
	{
		function oliver_single_navigation_html()
		{
			if (wp_attachment_is_image())
			{
				?>
					<nav class="nav-single">
						<div class="nav-previous">
							<div class="nav-desc">
								<?php
									previous_image_link(false, '<span class="meta-nav">&#8592;</span>' . esc_html__('Previous Image', 'oliver'));
								?>
							</div>
						</div>
						<div class="nav-next">
							<div class="nav-desc">
								<?php
									next_image_link(false, esc_html__('Next Image', 'oliver') . '<span class="meta-nav">&#8594;</span>');
								?>
							</div>
						</div>
					</nav>
				<?php
			}
			else
			{
				$previous_post_link = get_previous_post_link();
				$next_post_link     = get_next_post_link();
				
				if (($previous_post_link != "") || ($next_post_link != ""))
				{
					$previous_post = (is_attachment()) ? get_post(get_post()->post_parent) : get_adjacent_post(false, '', true);
					$next_post     = get_adjacent_post(false, '', false);
					
					?>
						<nav class="nav-single">
							<div class="nav-previous">
								<?php
									if ($previous_post &&  has_post_thumbnail($previous_post->ID))
									{
										$feat_img  = wp_get_attachment_image_src(get_post_thumbnail_id($previous_post->ID), 'oliver_image_size_5');
										$feat_img_alt = get_post_meta(get_post_thumbnail_id($previous_post->ID), '_wp_attachment_image_alt', true);
										
										?>
											<a class="nav-image-link" href="<?php echo get_permalink($previous_post->ID); ?>">
												<img alt="<?php echo esc_attr($feat_img_alt); ?>" src="<?php echo esc_url($feat_img[0]); ?>">
											</a>
										<?php
									}
								?>
								
								<?php
									previous_post_link('<div class="nav-desc"><h4>' . esc_html__('Previous Post', 'oliver') . '</h4>%link</div>',
													   '<span class="meta-nav">&#8592;</span> %title');
								?>
								
								<?php
									if ($previous_post)
									{
										?>
											<a class="nav-overlay-link" href="<?php echo get_permalink($previous_post->ID); ?>" rel="prev">
												<?php
													echo esc_html($previous_post->post_title);
												?>
											</a>
										<?php
									}
								?>
							</div>
							
							<div class="nav-next">
								<?php
									if ($next_post && has_post_thumbnail($next_post->ID))
									{
										$feat_img = wp_get_attachment_image_src(get_post_thumbnail_id($next_post->ID), 'oliver_image_size_5');
										$feat_img_alt = get_post_meta(get_post_thumbnail_id($next_post->ID), '_wp_attachment_image_alt', true);
										
										?>
											<a class="nav-image-link" href="<?php echo get_permalink($next_post->ID); ?>">
												<img alt="<?php echo esc_attr($feat_img_alt); ?>" src="<?php echo esc_url($feat_img[0]); ?>">
											</a>
										<?php
									}
								?>
								
								<?php
									next_post_link('<div class="nav-desc"><h4>' . esc_html__('Next Post', 'oliver') . '</h4>%link</div>',
												   '%title <span class="meta-nav">&#8594;</span>');
								?>
								
								<?php
									if ($next_post)
									{
										?>
											<a class="nav-overlay-link" href="<?php echo get_permalink($next_post->ID); ?>" rel="next">
												<?php
													echo esc_html($next_post->post_title);
												?>
											</a>
										<?php
									}
								?>
							</div>
						</nav>
					<?php
				}
			}
		}
	}
	
	
	if (! function_exists('oliver_single_navigation'))
	{
		function oliver_single_navigation()
		{
			$post_navigation = get_theme_mod('oliver_setting_post_navigation', 'Yes');
			
			if ($post_navigation != 'No')
			{
				oliver_single_navigation_html();
			}
		}
	}


/* ============================================================================================================================================= */


	function oliver_content_none()
	{
		if (is_404())
		{
			?>
				<article class="hentry page">
					<header class="entry-header">
						<h1 class="entry-title">
							<?php
								esc_html_e('you are lost!', 'oliver');
							?>
						</h1>
					</header>
					<div class="entry-content">
                        <div class="http-alert">
                            <h1>
								<i class="pw-icon-doc-alt"></i>
							</h1>
							<p>
								<?php
									esc_html_e('The page you are looking for was not found!', 'oliver');
								?>
							</p>
                            <p>
                            	<a class="button big" href="<?php echo esc_url(home_url('/')); ?>">
									<i class="pw-icon-home"></i>
									
									<?php
										esc_html_e('Return To Homepage', 'oliver');
									?>
								</a>
                            </p>
                        </div>
					</div>
				</article>
			<?php
		}
		elseif (is_search())
		{
			?>
				<article class="hentry page">
					<header class="entry-header">
						<h1 class="entry-title">
							<?php
								esc_html_e('nothing found', 'oliver');
							?>
						</h1>
					</header>
					<div class="entry-content">
						<div class="http-alert">
                            <h1>
								<i class="pw-icon-doc-alt"></i>
							</h1>
							<p>
								<?php
									esc_html_e('Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'oliver');
								?>
							</p>
							<?php
								get_search_form();
							?>
						</div>
					</div>
				</article>
			<?php
		}
		else
		{
			?>
				<article class="hentry page">
					<header class="entry-header">
						<h1 class="entry-title">
							<?php
								esc_html_e('nothing found', 'oliver');
							?>
						</h1>
					</header>
					<div class="entry-content">
						<div class="http-alert">
                            <h1>
								<i class="pw-icon-doc-alt"></i>
							</h1>
							<p>
								<?php
									esc_html_e('It seems we can not find what you are looking for. Perhaps searching can help.', 'oliver');
								?>
							</p>
							<?php
								get_search_form();
							?>
						</div>
					</div>
				</article>
			<?php
		}
	}


/* ============================================================================================================================================= */


	function oliver_meta_category()
	{
		?>
			<span class="cat-links">
				<span class="prefix">
					<?php
						esc_html_e('in', 'oliver');
					?>
				</span>
				<?php
					the_category(' ');
				?>
			</span>
		<?php
	}
	
	function oliver_meta_date()
	{
		?>
			<span class="posted-on">
				<span class="prefix">
					<?php
						esc_html_e('on', 'oliver');
					?>
				</span>
				<a href="<?php the_permalink(); ?>" rel="bookmark">
					<time class="entry-date published" datetime="<?php echo get_the_date('c'); ?>">
						<?php
							echo get_the_date();
						?>
					</time>
					<time class="updated" datetime="<?php echo get_the_modified_date('c'); ?>">
						<?php
							echo get_the_modified_date();
						?>
					</time>
				</a>
			</span>
		<?php
	}
	
	function oliver_meta_comment_hide_0()
	{
		?>
			<span class="comment-link">
				<span class="prefix">
					<?php
						esc_html_e('with', 'oliver');
					?>
				</span>
				<?php
					comments_popup_link(esc_html__('0 Comments', 'oliver'),
										esc_html__('1 Comment', 'oliver'),
										esc_html__('% Comments', 'oliver'),
										"",
										'Comments Off');
				?>
			</span>
		<?php
	}
	
	function oliver_meta_comment()
	{
		$meta_blog_comment_hide_0 = get_theme_mod('oliver_setting_meta_blog_comment_hide_0', true);
		$meta_post_comment_hide_0 = get_theme_mod('oliver_setting_meta_post_comment_hide_0', true);
		
		if (is_single())
		{
			if (get_comments_number() || (! $meta_post_comment_hide_0))
			{
				oliver_meta_comment_hide_0();
			}
		}
		else
		{
			if (get_comments_number() || (! $meta_blog_comment_hide_0))
			{
				oliver_meta_comment_hide_0();
			}
		}
	}
	
	function oliver_meta_author()
	{
		?>
			<span class="vcard author">
				<span class="prefix">
					<?php
						esc_html_e('by', 'oliver');
					?>
				</span>
				<a class="url fn n" href="<?php echo get_author_posts_url(get_the_author_meta('ID')); ?>">
					<span class="fn">
						<?php
							the_author();
						?>
					</span>
				</a>
			</span>
		<?php
	}
	
	function oliver_meta_like()
	{
		?>
			<span class="entry-like">
				<?php
					if (function_exists('dot_irecommendthis'))
					{
						dot_irecommendthis();
					}
				?>
			</span>
		<?php
	}
	
	function oliver_meta_share()
	{
		oliver_share_links_meta();
	}
	
	function oliver_meta_edit()
	{
		edit_post_link(esc_html__('Edit', 'oliver'),
					   '<span class="edit-link">',
					   '</span>');
	}
	
	
	function oliver_meta_wrap_position($meta_wrap_position, $meta_position, $meta_control)
	{
		$has_meta = false;
		$meta_position_category = $meta_position[0];
		$meta_position_date     = $meta_position[1];
		$meta_position_comment  = $meta_position[2];
		$meta_position_author   = $meta_position[3];
		$meta_position_share    = $meta_position[4];
		$meta_position_like     = $meta_position[5];
		$meta_position_edit     = $meta_position[6];
		
		if ($meta_position_category == $meta_wrap_position)
		{
			if (! $meta_control)
			{
				oliver_meta_category();
			}
			
			$has_meta = true;
		}
		
		if ($meta_position_date == $meta_wrap_position)
		{
			if (! $meta_control)
			{
				oliver_meta_date();
			}
			
			$has_meta = true;
		}
		
		if ($meta_position_comment == $meta_wrap_position)
		{
			if (! $meta_control)
			{
				oliver_meta_comment();
			}
			
			$has_meta = true;
		}
		
		if ($meta_position_author == $meta_wrap_position)
		{
			if (! $meta_control)
			{
				oliver_meta_author();
			}
			
			$has_meta = true;
		}
		
		if ($meta_position_share == $meta_wrap_position)
		{
			if (! $meta_control)
			{
				oliver_meta_share();
			}
			
			$has_meta = true;
		}
		
		if ($meta_position_like == $meta_wrap_position)
		{
			if (! $meta_control)
			{
				oliver_meta_like();
			}
			
			$has_meta = true;
		}
		
		if ($meta_position_edit == $meta_wrap_position)
		{
			if (! $meta_control)
			{
				oliver_meta_edit();
			}
			
			$has_meta = true;
		}
		
		return $has_meta;
	}
	
	
	function oliver_meta($meta_wrap_position)
	{
		$meta_position = array();
		
		if (is_singular('post'))
		{
			$meta_position = array(get_theme_mod('oliver_setting_meta_post_cat', 'below_title'),
								   get_theme_mod('oliver_setting_meta_post_date', 'below_title'),
								   get_theme_mod('oliver_setting_meta_post_comment', 'below_title'),
								   get_theme_mod('oliver_setting_meta_post_author', 'hidden'),
								   get_theme_mod('oliver_setting_meta_post_share', 'below_title'),
								   get_theme_mod('oliver_setting_meta_post_like', 'below_title'),
								   get_theme_mod('oliver_setting_meta_post_edit', 'hidden')
								   );
		}
		else
		{
			$meta_position = array(get_theme_mod('oliver_setting_meta_blog_cat', 'below_title'),
								   get_theme_mod('oliver_setting_meta_blog_date', 'below_title'),
								   get_theme_mod('oliver_setting_meta_blog_comment', 'hidden'),
								   get_theme_mod('oliver_setting_meta_blog_author', 'hidden'),
								   get_theme_mod('oliver_setting_meta_blog_share', 'below_title'),
								   get_theme_mod('oliver_setting_meta_blog_like', 'below_title'),
								   get_theme_mod('oliver_setting_meta_blog_edit', 'hidden')
								   );
		}
		
		if ($meta_wrap_position == 'above_title')
		{
			if (oliver_meta_wrap_position($meta_wrap_position, $meta_position, $meta_control = true))
			{
				?>
					<div class="entry-meta above-title">
						<?php
							oliver_meta_wrap_position($meta_wrap_position, $meta_position, $meta_control = false);
						?>
					</div> <!-- .entry-meta .above-title -->
				<?php
			}
		}
		elseif ($meta_wrap_position == 'below_title')
		{
			if (oliver_meta_wrap_position($meta_wrap_position, $meta_position, $meta_control = true))
			{
				?>
					<div class="entry-meta below-title">
						<?php
							oliver_meta_wrap_position($meta_wrap_position, $meta_position, $meta_control = false);
						?>
					</div> <!-- .entry-meta .below-title -->
				<?php
			}
		}
		elseif ($meta_wrap_position == 'below_content')
		{
			if (oliver_meta_wrap_position($meta_wrap_position, $meta_position, $meta_control = true))
			{
				?>
					<footer class="entry-meta below-content">
						<?php
							oliver_meta_wrap_position($meta_wrap_position, $meta_position, $meta_control = false);
						?>
					</footer> <!-- .entry-meta .below-content -->
				<?php
			}
		}
	}


/* ============================================================================================================================================= */


	function oliver_gallery_type__slider($atts)
	{
		extract(shortcode_atts(array('ids'     => "",
									 'orderby' => "",
									 'link'    => "",
									 'size'    => 'thumbnail'), $atts));
		
		$output = "";
		$items_with_commas = $ids;
		
		if ($items_with_commas != "")
		{
			$items_in_array = preg_split("/[\s]*[,][\s]*/", $items_with_commas);
			
			if ($orderby == 'rand')
			{
				shuffle($items_in_array);
			}
			
			$output .= '<div class="owl-carousel" data-items="1" data-loop="true" data-center="false" data-mouse-drag="true" data-nav="true" data-dots="true" data-autoplay="false" data-autoplay-speed="600" data-autoplay-timeout="2000">';
			
				if (is_page_template('page_template-full.php') || is_page_template('page_template-medium.php') || is_singular('portfolio'))
				{
					$size = 'oliver_image_size_7';
				}
				else
				{
					$size = 'oliver_image_size_1';
				}
				
				foreach ($items_in_array as $item)
				{
					$image 		   = wp_get_attachment_image_src($item, $size);
					$image_alt 	   = get_post_meta($item, '_wp_attachment_image_alt', true);
					$image_caption = get_post_field('post_excerpt', $item);
					
					if ($image_caption != "")
					{
						$image_caption = '<p class="owl-title">' . $image_caption . '</p>';
					}
					
					$output .= '<div>';
					$output .= '<img alt="' . esc_attr($image_alt) . '" src="' . esc_url($image[0]) . '">';
					$output .= $image_caption;
					$output .= '</div>';
				}
			
			$output .= '</div>';
		}
		
		return $output;
	}
	
	
	function oliver_gallery_type__grid($atts)
	{
		extract(shortcode_atts(array('ids'     => "",
									 'orderby' => "",
									 'link'    => "",
									 'size'    => 'thumbnail'), $atts));
		
		$output = "";
		$items_with_commas = $ids;
		
		if ($items_with_commas != "")
		{
			$items_in_array = preg_split("/[\s]*[,][\s]*/", $items_with_commas);
			
			if ( $orderby == 'rand' )
			{
				shuffle($items_in_array);
			}
			
			$output .= '<div class="gallery ' . (($link == "") ? 'link-to-attachment-page' : 'link-to-' . $link) . '">';
			
				foreach ($items_in_array as $item)
				{
					$image_big = "";
					$image_big_width_cropped = wp_get_attachment_image_src($item, 'oliver_image_size_7'); // magnific-popup-width
					
					if ($image_big_width_cropped[1] > $image_big_width_cropped[2])
					{
						$image_big = $image_big_width_cropped[0];
					}
					else
					{
						$image_big_height_cropped = wp_get_attachment_image_src($item, 'oliver_image_size_8'); // magnific-popup-height
						$image_big = $image_big_height_cropped[0];
					}
					
					$image_small = "";
					
					if ($size == 'full')
					{
						$image_small = wp_get_attachment_image_src($item, 'oliver_image_size_1'); // gallery-type-grid
					}
					else
					{
						$image_small = wp_get_attachment_image_src($item, 'oliver_image_size_6'); // gallery-type-grid
					}
					
					$image_alt 	   = get_post_meta($item, '_wp_attachment_image_alt', true);
					$image_caption = get_post_field('post_excerpt', $item);
					
					if ($image_caption != "")
					{
						$image_caption = '<figcaption class="wp-caption-text gallery-caption">' . $image_caption . '</figcaption>';
					}
					
					if ($link == 'file')
					{
						$output .= '<figure class="gallery-item">';
						$output .= '<div class="gallery-icon landscape">';
						$output .= '<a href="' . esc_url($image_big) . '">';
						$output .= '<img class="attachment-thumbnail" alt="' . esc_attr($image_alt) . '" src="' . esc_url($image_small[0]) . '">';
						$output .= '</a>';
						$output .= '</div>';
						$output .= $image_caption;
						$output .= '</figure>';
					}
					elseif ($link == 'none')
					{
						$output .= '<figure class="gallery-item">';
						$output .= '<div class="gallery-icon landscape">';
						$output .= '<img class="attachment-thumbnail" alt="' . esc_attr($image_alt) . '" src="' . esc_url($image_small[0]) . '">';
						$output .= '</div>';
						$output .= $image_caption;
						$output .= '</figure>';
					}
					else
					{
						$attachment_page = get_attachment_link($item);
						
						$output .= '<figure class="gallery-item">';
						$output .= '<div class="gallery-icon landscape">';
						$output .= '<a href="' . esc_url($attachment_page) . '">';
						$output .= '<img class="attachment-thumbnail" alt="' . esc_attr($image_alt) . '" src="' . esc_url($image_small[0]) . '">';
						$output .= '</a>';
						$output .= '</div>';
						$output .= $image_caption;
						$output .= '</figure>';
					}
				}
			
			$output .= '</div>';
		}
		
		return $output;
	}
	
	
	function oliver_portfolio_page__lightbox_gallery($atts)
	{
		extract(shortcode_atts(array('ids'     => "",
									 'orderby' => "",
									 'link'    => "",
									 'size'    => 'thumbnail'), $atts));
		
		$output = "";
		$items_with_commas = $ids;
		
		if ($items_with_commas != "")
		{
			$items_in_array = preg_split("/[\s]*[,][\s]*/", $items_with_commas);
			
			if ($orderby == 'rand')
			{
				shuffle($items_in_array);
			}
			
				$first_item = true;
				global $oliver_portfolio_item_has_feat_img;
				$feat_img = $oliver_portfolio_item_has_feat_img;
				global $oliver_portfolio_page_grid_type__lightbox_gallery;
				
				foreach ($items_in_array as $item)
				{
					$image_big = "";
					$image_big_width_cropped = wp_get_attachment_image_src($item, 'oliver_image_size_7'); // magnific-popup-width
					
					if ($image_big_width_cropped[1] > $image_big_width_cropped[2])
					{
						$image_big = $image_big_width_cropped[0];
					}
					else
					{
						$image_big_height_cropped = wp_get_attachment_image_src($item, 'oliver_image_size_8'); // magnific-popup-height
						$image_big = $image_big_height_cropped[0];
					}
					
					$image_caption = get_post_field('post_excerpt', $item);
					
					if ($image_caption != "")
					{
						$image_caption = 'title="' . esc_attr($image_caption) . '"';
					}
					
					if ($first_item)
					{
						if ($feat_img)
						{
							$output .= '<a class="lightbox" ' . $image_caption . ' href="' . esc_url($image_big) . '">' . oliver_portfolio_item_feat_img__lightbox_gallery($oliver_portfolio_page_grid_type__lightbox_gallery) . '</a>';
						}
						else
						{
							$output .= '<a class="lightbox" ' . $image_caption . ' href="' . esc_url($image_big) . '">' . get_the_title() . '</a>';
						}
						
						$first_item = false;
					}
					else
					{
						$output .= '<a class="lightbox" ' . $image_caption . ' href="' . esc_url($image_big) . '"></a>';
					}
				}
		}
		
		return $output;
	}
	
	
	function oliver_post_gallery($output = "", $atts = null, $content = false, $tag = false)
	{
		$new_output = $output;
		
		
		if ((is_page_template('page_template-portfolio.php') || is_page_template('page_template-portfolio-narrow.php') || is_page_template('page_template-portfolio-full.php') || is_tax('portfolio-category')) && has_post_format('gallery'))
		{
			$new_output = oliver_portfolio_page__lightbox_gallery($atts);
		}
		else
		{
			$gallery_type = get_option('oliver_gallery_type' . '__' . get_the_ID(), 'grid');
			
			if ($gallery_type == 'slider')
			{
				$new_output = oliver_gallery_type__slider($atts);
			}
			else
			{
				$new_output = oliver_gallery_type__grid($atts);
			}
		}
		
		
		return $new_output;
	}
	
	add_filter('post_gallery', 'oliver_post_gallery', 10, 4);


/* ============================================================================================================================================= */


	function oliver_meta_box__title_visibility($post)
	{
		?>
			<?php
				wp_nonce_field('oliver_meta_box__title_visibility',
							   'oliver_meta_box_nonce__title_visibility');
			?>
			<p>
				<?php
					$oliver_title_visibility = get_option(get_the_ID() . 'oliver_title_visibility', false);
				?>
				<label for="oliver_title_visibility">
					<input type="checkbox" id="oliver_title_visibility" name="oliver_title_visibility" <?php if ($oliver_title_visibility == true) { echo 'checked="checked"'; } ?>>
					<?php esc_html_e('Hide Title', 'oliver'); ?>
				</label>
			</p>
		<?php
	}
	
	
	function oliver_meta_box_save__title_visibility($post_id)
	{
		if (! isset($_POST['oliver_meta_box_nonce__title_visibility']))
		{
			return $post_id;
		}
		
		$nonce = $_POST['oliver_meta_box_nonce__title_visibility'];
		
		if (! wp_verify_nonce($nonce, 'oliver_meta_box__title_visibility'))
        {
			return $post_id;
		}
		
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
        {
			return $post_id;
		}
		
		if ('page' == $_POST['post_type'])
		{
			if (! current_user_can('edit_page', $post_id))
			{
				return $post_id;
			}
		}
		else
		{
			if (! current_user_can('edit_post', $post_id))
			{
				return $post_id;
			}
		}
		
		update_option($post_id . 'oliver_title_visibility', $_POST['oliver_title_visibility']);
	}
	
	add_action('save_post', 'oliver_meta_box_save__title_visibility');
	
	
	function oliver_add_meta_boxes__title_visibility()
	{
		add_meta_box('oliver_add_meta_box__title_visibility',
					 esc_html__('Title Visibility', 'oliver'),
					 'oliver_meta_box__title_visibility',
					 array('page'),
					 'side',
					 'high');
	}
	
	add_action('add_meta_boxes', 'oliver_add_meta_boxes__title_visibility');


/* ============================================================================================================================================= */


	function oliver_meta_box__featured_video($post)
	{
		?>
			<?php
				wp_nonce_field('oliver_meta_box__featured_video',
							   'oliver_meta_box_nonce__featured_video');
			?>
			<p>
				<label for="oliver_featured_video_url"><?php esc_html_e('URL', 'oliver'); ?></label>
				<?php
					$oliver_featured_video_url          = stripcslashes(get_option(get_the_ID() . 'oliver_featured_video_url', ""));
					$oliver_featured_video_url__new_tab = get_option(get_the_ID() . 'oliver_featured_video_url__new_tab', true);
				?>
				<input type="text" id="oliver_featured_video_url" name="oliver_featured_video_url" class="widefat" value="<?php echo esc_url($oliver_featured_video_url); ?>">
				<span id="oliver_featured_video__new_tab">
					<label style="font-size: 12px; color: #777777;">
						<input type="checkbox" name="oliver_featured_video_url__new_tab" <?php if ($oliver_featured_video_url__new_tab != false) { echo 'checked="checked"'; } ?>> <?php esc_html_e('Open In New Tab', 'oliver'); ?> <span style="color: #999999;"><?php esc_html_e('(for Link format)', 'oliver'); ?></span>
					</label>
				</span>
			</p>
			
			<p class="howto oliver_featured_video__howto_post">
				<?php
					esc_html_e('Audio: Just paste the browser address url of an audio from SoundCloud. This audio will be shown in place of featured image.', 'oliver');
				?>
				<br>
				<br>
				<?php
					esc_html_e('Video: Just paste the browser address url of a video from YouTube or Vimeo. This video will be shown in place of featured image.', 'oliver');
				?>
			</p>
			<p class="howto oliver_featured_video__howto_portfolio">
				<?php
					esc_html_e('Use this URL field for format; Link, Audio and Video.', 'oliver');
				?>
				<br>
				<br>
				<?php
					esc_html_e('- Link: Enter your custom url.', 'oliver');
				?>
				<br>
				<br>
				<?php
					esc_html_e('- Audio: Use browser address url of an audio from SoundCloud. This audio will be shown in a lightbox in your portfolio page.', 'oliver');
				?>
				<br>
				<br>
				<?php
					esc_html_e('- Video: Use browser address url of a video from YouTube or Vimeo. This video will be shown in a lightbox in your portfolio page.', 'oliver');
				?>
			</p>
		<?php
	}
	
	
	function oliver_meta_box_save__featured_video($post_id)
	{
		if (! isset($_POST['oliver_meta_box_nonce__featured_video']))
		{
			return $post_id;
		}
		
		$nonce = $_POST['oliver_meta_box_nonce__featured_video'];
		
		if (! wp_verify_nonce($nonce, 'oliver_meta_box__featured_video'))
        {
			return $post_id;
		}
		
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
        {
			return $post_id;
		}
		
		if ('page' == $_POST['post_type'])
		{
			if (! current_user_can('edit_page', $post_id))
			{
				return $post_id;
			}
		}
		else
		{
			if (! current_user_can('edit_post', $post_id))
			{
				return $post_id;
			}
		}
		
		update_option($post_id . 'oliver_featured_video_url', $_POST['oliver_featured_video_url']);
		update_option($post_id . 'oliver_featured_video_url__new_tab', $_POST['oliver_featured_video_url__new_tab']);
	}
	
	add_action('save_post', 'oliver_meta_box_save__featured_video');
	
	
	function oliver_add_meta_boxes__featured_video()
	{
		add_meta_box('oliver_add_meta_box__featured_video__post',
					 esc_html__('Featured Audio/Video', 'oliver'),
					 'oliver_meta_box__featured_video',
					 array('post'),
					 'side',
					 'low');
		
		add_meta_box('oliver_add_meta_box__featured_video__portfolio',
					 esc_html__('Featured Audio/Video/Link', 'oliver'),
					 'oliver_meta_box__featured_video',
					 array('portfolio'),
					 'side',
					 'low');
	}
	
	add_action('add_meta_boxes', 'oliver_add_meta_boxes__featured_video');


/* ============================================================================================================================================= */


	function oliver_meta_box__gallery_type($post)
	{
		?>
			<div class="admin-inside-box">
				<?php
					wp_nonce_field('oliver_meta_box__gallery_type', 'oliver_meta_box_nonce__gallery_type');
				?>
				<p>
					<label for="oliver_gallery_type"><?php esc_html_e('Select Gallery Type', 'oliver'); ?></label>
					<?php
						$gallery_type = get_option('oliver_gallery_type' . '__' . get_the_ID(), 'grid');
					?>
					<select id="oliver_gallery_type" name="oliver_gallery_type" style="min-width: 100px;">
						<option <?php if ($gallery_type == 'grid') { echo 'selected="selected"'; } ?> value="grid"><?php esc_html_e('Grid', 'oliver'); ?></option>
						<option <?php if ($gallery_type == 'slider') { echo 'selected="selected"'; } ?> value="slider"><?php esc_html_e('Slider', 'oliver'); ?></option>
					</select>
				</p>
				<p class="howto">
					<?php
						esc_html_e('Create galleries from Add Media button above the content editor.', 'oliver');
					?>
				</p>
				<p class="howto">
					<?php
						esc_html_e('And select gallery type from here. You can turn your gallery into a slider.', 'oliver');
					?>
				</p>
				<p class="howto">
					<?php
						esc_html_e('To show your images in a lightbox, select Grid type then edit your gallery in the content editor and choose Link To: Media File from gallery settings.', 'oliver');
					?>
				</p>
			</div>
		<?php
	}
	
	
	function oliver_save_meta_box__gallery_type($post_id)
	{
		if (! isset($_POST['oliver_meta_box_nonce__gallery_type']))
		{
			return $post_id;
		}
		
		$nonce = $_POST['oliver_meta_box_nonce__gallery_type'];
		
		if (! wp_verify_nonce($nonce, 'oliver_meta_box__gallery_type'))
        {
			return $post_id;
		}
		
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) 
        {
			return $post_id;
		}
		
		if ('page' == $_POST['post_type'])
		{
			if (! current_user_can('edit_page', $post_id))
			{
				return $post_id;
			}
		}
		else
		{
			if (! current_user_can('edit_post', $post_id))
			{
				return $post_id;
			}
		}
		
		update_option('oliver_gallery_type' . '__' . $post_id, $_POST['oliver_gallery_type']);
	}
	
	add_action('save_post', 'oliver_save_meta_box__gallery_type');
	
	
	function oliver_add_meta_boxes__gallery_type()
	{
		add_meta_box('oliver_add_meta_box__gallery_type',
					 esc_html__('Gallery Type', 'oliver'),
					 'oliver_meta_box__gallery_type',
					 array('post', 'page', 'portfolio'),
					 'side',
					 'low');
	}
	
	add_action('add_meta_boxes', 'oliver_add_meta_boxes__gallery_type');


/* ============================================================================================================================================= */


	function oliver_meta_box__sidebar($post)
	{
		?>
			<div class="admin-inside-box">
				<?php
					wp_nonce_field('oliver_meta_box__sidebar', 'oliver_meta_box_nonce__sidebar');
				?>
				<p>
					<label for="oliver_select_page_sidebar"><?php esc_html_e('Select Sidebar', 'oliver'); ?></label>
					<?php
						$select_page_sidebar = get_option('oliver_select_page_sidebar' . '__' . get_the_ID(), 'No Sidebar');
					?>
					<select id="oliver_select_page_sidebar" name="oliver_select_page_sidebar">
						<option <?php if ($select_page_sidebar == 'No Sidebar') { echo 'selected="selected"'; } ?> value="No Sidebar"><?php esc_html_e('No Sidebar', 'oliver'); ?></option>
						<option <?php if ($select_page_sidebar == 'oliver_sidebar_1') { echo 'selected="selected"'; } ?> value="oliver_sidebar_1"><?php esc_html_e('Blog Sidebar', 'oliver'); ?></option>
						<option <?php if ($select_page_sidebar == 'oliver_sidebar_2') { echo 'selected="selected"'; } ?> value="oliver_sidebar_2"><?php esc_html_e('Post Sidebar', 'oliver'); ?></option>
						<option <?php if ($select_page_sidebar == 'oliver_sidebar_3') { echo 'selected="selected"'; } ?> value="oliver_sidebar_3"><?php esc_html_e('Page Sidebar', 'oliver'); ?></option>
						<option <?php if ($select_page_sidebar == 'oliver_sidebar_15') { echo 'selected="selected"'; } ?> value="oliver_sidebar_15"><?php esc_html_e('Portfolio Sidebar', 'oliver'); ?></option>
						<?php
							$oliver_sidebars_with_commas = get_option('oliver_sidebars_with_commas');
							
							if ($oliver_sidebars_with_commas != "")
							{
								$sidebars = preg_split("/[\s]*[,][\s]*/", $oliver_sidebars_with_commas);
								
								foreach ($sidebars as $sidebar_name)
								{
									$selected = "";
									
									if ($select_page_sidebar == $sidebar_name)
									{
										$selected = 'selected="selected"';
									}
									
									echo '<option ' . $selected . ' value="' . esc_attr($sidebar_name) . '">' . $sidebar_name . '</option>';
								}
							}
						?>
					</select>
				</p>
				<p class="howto">
					<?php
						esc_html_e('Sidebar is a widget area. You can find all available sidebars in your Widgets page under Appearance menu or Widgets section in Customizer.', 'oliver');
					?>
				</p>
				<p class="howto">
					<?php
						esc_html_e('Also you can create new sidebars from Appearance > Theme Options > Sidebar.', 'oliver');
					?>
				</p>
			</div>
		<?php
	}
	
	
	function oliver_save_meta_box__sidebar($post_id)
	{
		if (! isset($_POST['oliver_meta_box_nonce__sidebar']))
		{
			return $post_id;
		}
		
		$nonce = $_POST['oliver_meta_box_nonce__sidebar'];
		
		if (! wp_verify_nonce($nonce, 'oliver_meta_box__sidebar'))
        {
			return $post_id;
		}
		
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) 
        {
			return $post_id;
		}
		
		if ('page' == $_POST['post_type'])
		{
			if (! current_user_can('edit_page', $post_id))
			{
				return $post_id;
			}
		}
		else
		{
			if (! current_user_can('edit_post', $post_id))
			{
				return $post_id;
			}
		}
		
		update_option('oliver_select_page_sidebar' . '__' . $post_id, $_POST['oliver_select_page_sidebar']);
	}
	
	add_action('save_post', 'oliver_save_meta_box__sidebar');
	
	
	function oliver_add_meta_boxes__sidebar()
	{
		add_meta_box('oliver_add_meta_box__sidebar',
					 esc_html__('Sidebar', 'oliver'),
					 'oliver_meta_box__sidebar',
					 array('page'),
					 'side',
					 'low');
	}
	
	add_action('add_meta_boxes', 'oliver_add_meta_boxes__sidebar');


/* ============================================================================================================================================= */


	function oliver_meta_box__featured_area($post)
	{
		?>
			<div class="admin-inside-box">
				<?php
					wp_nonce_field('oliver_meta_box__featured_area', 'oliver_meta_box_nonce__featured_area');
				?>
				<p>
					<label for="oliver_select_page_featured_area"><?php esc_html_e('Select Featured Area', 'oliver'); ?></label>
					<?php
						$select_page_featured_area = get_option('oliver_select_page_featured_area' . '__' . get_the_ID(), 'No Featured Area');
					?>
					<select id="oliver_select_page_featured_area" name="oliver_select_page_featured_area">
						<option <?php if ($select_page_featured_area == 'No Featured Area') { echo 'selected="selected"'; } ?> value="No Featured Area"><?php esc_html_e('No Featured Area', 'oliver'); ?></option>
						<option <?php if ($select_page_featured_area == 'oliver_sidebar_13') { echo 'selected="selected"'; } ?> value="oliver_sidebar_13"><?php esc_html_e('Blog Featured Area', 'oliver'); ?></option>
						<option <?php if ($select_page_featured_area == 'oliver_sidebar_14') { echo 'selected="selected"'; } ?> value="oliver_sidebar_14"><?php esc_html_e('Page Featured Area', 'oliver'); ?></option>
						<option <?php if ($select_page_featured_area == 'oliver_sidebar_17') { echo 'selected="selected"'; } ?> value="oliver_sidebar_17"><?php esc_html_e('Portfolio Featured Area', 'oliver'); ?></option>
						<option <?php if ($select_page_featured_area == 'oliver_sidebar_18') { echo 'selected="selected"'; } ?> value="oliver_sidebar_18"><?php esc_html_e('Shop Featured Area', 'oliver'); ?></option>
						<?php
							$oliver_sidebars_with_commas = get_option('oliver_sidebars_with_commas');
							
							if ($oliver_sidebars_with_commas != "")
							{
								$sidebars = preg_split("/[\s]*[,][\s]*/", $oliver_sidebars_with_commas);
								
								foreach ($sidebars as $sidebar_name)
								{
									$selected = "";
									
									if ($select_page_featured_area == $sidebar_name)
									{
										$selected = 'selected="selected"';
									}
									
									echo '<option ' . $selected . ' value="' . esc_attr($sidebar_name) . '">' . $sidebar_name . '</option>';
								}
							}
						?>
					</select>
				</p>
				<p class="howto">
					<?php
						esc_html_e('Featured Area is a widget area like sidebars. So you can create new one from Appearance > Theme Options > Sidebar.', 'oliver');
					?>
				</p>
				<p class="howto">
					<?php
						esc_html_e('Add Main Slider, Link Box or Intro widgets to your featured area. You can add many widgets to a featured area.', 'oliver');
					?>
				</p>
			</div>
		<?php
	}
	
	
	function oliver_save_meta_box__featured_area($post_id)
	{
		if (! isset($_POST['oliver_meta_box_nonce__featured_area']))
		{
			return $post_id;
		}
		
		$nonce = $_POST['oliver_meta_box_nonce__featured_area'];
		
		if (! wp_verify_nonce($nonce, 'oliver_meta_box__featured_area'))
        {
			return $post_id;
		}
		
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) 
        {
			return $post_id;
		}
		
		if ('page' == $_POST['post_type'])
		{
			if (! current_user_can('edit_page', $post_id))
			{
				return $post_id;
			}
		}
		else
		{
			if (! current_user_can('edit_post', $post_id))
			{
				return $post_id;
			}
		}
		
		update_option('oliver_select_page_featured_area' . '__' . $post_id, $_POST['oliver_select_page_featured_area']);
	}
	
	add_action('save_post', 'oliver_save_meta_box__featured_area');
	
	
	function oliver_add_meta_boxes__featured_area()
	{
		add_meta_box('oliver_add_meta_box__featured_area',
					 esc_html__('Featured Area', 'oliver'),
					 'oliver_meta_box__featured_area',
					 array('page'),
					 'side',
					 'low');
	}
	
	add_action('add_meta_boxes', 'oliver_add_meta_boxes__featured_area');


/* ============================================================================================================================================= */


	function oliver_meta_box__post_style($post)
	{
		?>
			<div class="admin-inside-box">
				<?php
					wp_nonce_field('oliver_meta_box__post_style', 'oliver_meta_box_nonce__post_style');
				?>
				<p>
					<label for="oliver_post_style"><?php esc_html_e('Select Post Style', 'oliver'); ?></label>
					<?php
						$post_style = get_option('oliver_post_style' . '__' . get_the_ID(), 'inherit');
					?>
					<select id="oliver_post_style" name="oliver_post_style">
						<option <?php if ($post_style == 'inherit') { echo 'selected="selected"'; } ?> value="inherit"><?php esc_html_e('Inherit from Customizer', 'oliver'); ?></option>
						<option <?php if ($post_style == 'post-header-classic') { echo 'selected="selected"'; } ?> value="post-header-classic"><?php esc_html_e('Classic', 'oliver'); ?></option>
						<option <?php if ($post_style == 'is-top-content-single-medium') { echo 'selected="selected"'; } ?> value="is-top-content-single-medium"><?php esc_html_e('Classic Medium', 'oliver'); ?></option>
						<option <?php if ($post_style == 'is-top-content-single-medium with-parallax') { echo 'selected="selected"'; } ?> value="is-top-content-single-medium with-parallax"><?php esc_html_e('Classic Medium Parallax', 'oliver'); ?></option>
						<option <?php if ($post_style == 'is-top-content-single-full') { echo 'selected="selected"'; } ?> value="is-top-content-single-full"><?php esc_html_e('Classic Full', 'oliver'); ?></option>
						<option <?php if ($post_style == 'is-top-content-single-full with-parallax') { echo 'selected="selected"'; } ?> value="is-top-content-single-full with-parallax"><?php esc_html_e('Classic Full Parallax', 'oliver'); ?></option>
						<option <?php if ($post_style == 'is-top-content-single-full-margins') { echo 'selected="selected"'; } ?> value="is-top-content-single-full-margins"><?php esc_html_e('Classic Full with Margins', 'oliver'); ?></option>
						<option <?php if ($post_style == 'is-top-content-single-full-margins with-parallax') { echo 'selected="selected"'; } ?> value="is-top-content-single-full-margins with-parallax"><?php esc_html_e('Classic Full with Margins Parallax', 'oliver'); ?></option>
						<option <?php if ($post_style == 'post-header-overlay post-header-overlay-inline is-post-dark') { echo 'selected="selected"'; } ?> value="post-header-overlay post-header-overlay-inline is-post-dark"><?php esc_html_e('Overlay', 'oliver'); ?></option>
						<option <?php if ($post_style == 'is-top-content-single-medium with-overlay') { echo 'selected="selected"'; } ?> value="is-top-content-single-medium with-overlay"><?php esc_html_e('Overlay Medium', 'oliver'); ?></option>
						<option <?php if ($post_style == 'is-top-content-single-full with-overlay') { echo 'selected="selected"'; } ?> value="is-top-content-single-full with-overlay"><?php esc_html_e('Overlay Full', 'oliver'); ?></option>
						<option <?php if ($post_style == 'is-top-content-single-full-margins with-overlay') { echo 'selected="selected"'; } ?> value="is-top-content-single-full-margins with-overlay"><?php esc_html_e('Overlay Full with Margins', 'oliver'); ?></option>
						<option <?php if ($post_style == 'is-top-content-single-medium with-title-full') { echo 'selected="selected"'; } ?> value="is-top-content-single-medium with-title-full"><?php esc_html_e('Title Full', 'oliver'); ?></option>
						<option <?php if ($post_style == 'post-header-classic is-featured-image-left') { echo 'selected="selected"'; } ?> value="post-header-classic is-featured-image-left"><?php esc_html_e('Image Left', 'oliver'); ?></option>
						<option <?php if ($post_style == 'post-header-classic is-featured-image-right') { echo 'selected="selected"'; } ?> value="post-header-classic is-featured-image-right"><?php esc_html_e('Image Right', 'oliver'); ?></option>
					</select>
				</p>
				<p class="howto">
					<?php
						esc_html_e('Inherit from Customizer: Appearance > Customize > Single Post > Post Style.', 'oliver');
					?>
					<br>
					<br>
					<?php
						esc_html_e('- Classic style applies if there is no featured media.', 'oliver');
					?>
					<br>
					<?php
						esc_html_e('- Image Left and Right layouts display as classic style when featured video is present.', 'oliver');
					?>
				</p>
			</div>
		<?php
	}
	
	
	function oliver_save_meta_box__post_style($post_id)
	{
		if (! isset($_POST['oliver_meta_box_nonce__post_style']))
		{
			return $post_id;
		}
		
		$nonce = $_POST['oliver_meta_box_nonce__post_style'];
		
		if (! wp_verify_nonce($nonce, 'oliver_meta_box__post_style'))
        {
			return $post_id;
		}
		
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) 
        {
			return $post_id;
		}
		
		if ('page' == $_POST['post_type'])
		{
			if (! current_user_can('edit_page', $post_id))
			{
				return $post_id;
			}
		}
		else
		{
			if (! current_user_can('edit_post', $post_id))
			{
				return $post_id;
			}
		}
		
		update_option('oliver_post_style' . '__' . $post_id, $_POST['oliver_post_style']);
	}
	
	add_action('save_post', 'oliver_save_meta_box__post_style');
	
	
	function oliver_add_meta_boxes__post_style()
	{
		add_meta_box('oliver_add_meta_box__post_style',
					 esc_html__('Post Style', 'oliver'),
					 'oliver_meta_box__post_style',
					 array('post'),
					 'side',
					 'high');
	}
	
	add_action('add_meta_boxes', 'oliver_add_meta_boxes__post_style');


/* ============================================================================================================================================= */


	/*
		This function filters the post content when viewing a post with the "chat" post format.  It formats the 
		content with structured HTML markup to make it easy for theme developers to style chat posts. The 
		advantage of this solution is that it allows for more than two speakers (like most solutions). You can 
		have 100s of speakers in your chat post, each with their own, unique classes for styling.
		
		@author David Chandra
		@link http://www.turtlepod.org
		@author Justin Tadlock
		@link http://justintadlock.com
		@copyright Copyright (c) 2012
		@license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
		@link http://justintadlock.com/archives/2012/08/21/post-formats-chat
		
		@global array $_post_format_chat_ids An array of IDs for the chat rows based on the author.
		@param string $content The content of the post.
		@return string $chat_output The formatted content of the post.
	*/
	
	function oliver_theme_post_format_chat_content( $content )
	{
		global $_post_format_chat_ids;
		
		/* If this is not a 'chat' post, return the content. */
		if ( !has_post_format( 'chat' ) )
		{
			return $content;
		}
		
		/* Set the global variable of speaker IDs to a new, empty array for this chat. */
		$_post_format_chat_ids = array();
		
		/* Allow the separator (separator for speaker/text) to be filtered. */
		$separator = apply_filters( 'my_post_format_chat_separator', ':' );
		
		/* Open the chat transcript div and give it a unique ID based on the post ID. */
		$chat_output = "\n\t\t\t" . '<div id="chat-transcript-' . esc_attr( get_the_ID() ) . '" class="chat-transcript">';
		
		/* Split the content to get individual chat rows. */
		$chat_rows = preg_split( "/(\r?\n)+|(<br\s*\/?>\s*)+/", $content );
		
		/* Loop through each row and format the output. */
		foreach ( $chat_rows as $chat_row )
		{
			/* If a speaker is found, create a new chat row with speaker and text. */
			if ( strpos( $chat_row, $separator ) )
			{
				/* Split the chat row into author/text. */
				$chat_row_split = explode( $separator, trim( $chat_row ), 2 );
				
				/* Get the chat author and strip tags. */
				$chat_author = strip_tags( trim( $chat_row_split[0] ) );
				
				/* Get the chat text. */
				$chat_text = trim( $chat_row_split[1] );
				
				/* Get the chat row ID (based on chat author) to give a specific class to each row for styling. */
				$speaker_id = oliver_theme_post_format_chat_row_id( $chat_author );
				
				/* Open the chat row. */
				$chat_output .= "\n\t\t\t\t" . '<div class="chat-row ' . sanitize_html_class( "chat-speaker-{$speaker_id}" ) . '">';
				
				/* Add the chat row author. */
				$chat_output .= "\n\t\t\t\t\t" . '<div class="chat-author ' . sanitize_html_class( strtolower( "chat-author-{$chat_author}" ) ) . ' vcard"><cite class="fn">' . apply_filters( 'my_post_format_chat_author', $chat_author, $speaker_id ) . '</cite>' . $separator . '</div>';
				
				/* Add the chat row text. */
				$chat_output .= "\n\t\t\t\t\t" . '<div class="chat-text"><p>' . str_replace( array( "\r", "\n", "\t" ), '', apply_filters( 'my_post_format_chat_text', $chat_text, $chat_author, $speaker_id ) ) . '</p></div>';
				
				/* Close the chat row. */
				$chat_output .= "\n\t\t\t\t" . '</div><!-- .chat-row -->';
			}
			/*
				If no author is found, assume this is a separate paragraph of text that belongs to the
				previous speaker and label it as such, but let's still create a new row.
			*/
			else
			{
				/* Make sure we have text. */
				if ( !empty( $chat_row ) )
				{
					/* Open the chat row. */
					$chat_output .= "\n\t\t\t\t" . '<div class="chat-row ' . sanitize_html_class( "chat-speaker-{$speaker_id}" ) . '">';
					
					/* Don't add a chat row author.  The label for the previous row should suffice. */
					
					/* Add the chat row text. */
					$chat_output .= "\n\t\t\t\t\t" . '<div class="chat-text"><p>' . str_replace( array( "\r", "\n", "\t" ), '', apply_filters( 'my_post_format_chat_text', $chat_row, $chat_author, $speaker_id ) ) . '</p></div>';
					
					/* Close the chat row. */
					$chat_output .= "\n\t\t\t</div><!-- .chat-row -->";
				}
			}
		}
		
		/* Close the chat transcript div. */
		$chat_output .= "\n\t\t\t</div><!-- .chat-transcript -->\n";
		
		/* Return the chat content and apply filters for developers. */
		return apply_filters( 'my_post_format_chat_content', $chat_output );
	}
	
	/*
		This function returns an ID based on the provided chat author name. It keeps these IDs in a global 
		array and makes sure we have a unique set of IDs.  The purpose of this function is to provide an "ID"
		that will be used in an HTML class for individual chat rows so they can be styled. So, speaker "John" 
		will always have the same class each time he speaks. And, speaker "Mary" will have a different class 
		from "John" but will have the same class each time she speaks.
		
		@author David Chandra
		@link http://www.turtlepod.org
		@author Justin Tadlock
		@link http://justintadlock.com
		@copyright Copyright (c) 2012
		@license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
		@link http://justintadlock.com/archives/2012/08/21/post-formats-chat
		
		@global array $_post_format_chat_ids An array of IDs for the chat rows based on the author.
		@param string $chat_author Author of the current chat row.
		@return int The ID for the chat row based on the author.
	*/
	
	function oliver_theme_post_format_chat_row_id( $chat_author )
	{
		global $_post_format_chat_ids;
		
		/* Let's sanitize the chat author to avoid craziness and differences like "John" and "john". */
		$chat_author = strtolower( strip_tags( $chat_author ) );
		
		/* Add the chat author to the array. */
		$_post_format_chat_ids[] = $chat_author;
		
		/* Make sure the array only holds unique values. */
		$_post_format_chat_ids = array_unique( $_post_format_chat_ids );
		
		/* Return the array key for the chat author and add "1" to avoid an ID of "0". */
		return absint( array_search( $chat_author, $_post_format_chat_ids ) ) + 1;
	}
	
	/* Filter the content of chat posts. */
	add_filter( 'the_content', 'oliver_theme_post_format_chat_content' );


/* ============================================================================================================================================= */


	function oliver_customize_register($wp_customize)
	{
		$wp_customize->add_panel('oliver_panel_general',
								 array('title'       => esc_html__('General', 'oliver'),
									   'description' => esc_html__('General options.', 'oliver'),
									   'priority'    => 1));
		
				$wp_customize->add_section('oliver_section_layout',
										   array('title'       => esc_html__('Layout', 'oliver'),
												 'description' => esc_html__('Set theme layout.', 'oliver'),
												 'panel'       => 'oliver_panel_general',
												 'priority'    => 2));
				
				$wp_customize->add_section('oliver_section_fonts',
										   array('title'       => esc_html__('Fonts', 'oliver'),
												 'description' => esc_html__('Theme font settings.', 'oliver'),
												 'panel'       => 'oliver_panel_general',
												 'priority'    => 3));
			
				$wp_customize->add_section('oliver_section_chars',
										   array('title'       => esc_html__('Characters', 'oliver'),
												 'description' => esc_html__('Set character sets.', 'oliver'),
												 'panel'       => 'oliver_panel_general',
												 'priority'    => 4));
				
				$wp_customize->add_section('oliver_section_colors',
										   array('title'       => esc_html__('Colors', 'oliver'),
												 'description' => esc_html__('Select theme colors.', 'oliver'),
												 'panel'       => 'oliver_panel_general',
												 'priority'    => 5));
		
		
		$wp_customize->add_panel('oliver_panel_header',
								 array('title'       => esc_html__('Header', 'oliver'),
									   'description' => esc_html__('Theme header options.', 'oliver'),
									   'priority'    => 21));
				
				$wp_customize->add_section('oliver_section_header_general',
										   array('title'       => esc_html__('General', 'oliver'),
												 'description' => esc_html__('General header options.', 'oliver'),
												 'panel'       => 'oliver_panel_header',
												 'priority'    => 22));
				
				$wp_customize->add_section('oliver_section_header_menu',
										   array('title'       => esc_html__('Menu', 'oliver'),
												 'description' => esc_html__('Navigation menu options.', 'oliver'),
												 'panel'       => 'oliver_panel_header',
												 'priority'    => 23));
		
		
		$wp_customize->add_section('oliver_section_footer',
								   array('title'       => esc_html__('Footer', 'oliver'),
										 'description' => esc_html__('Theme footer options.', 'oliver'),
										 'priority'    => 24));
		
		
		$wp_customize->add_panel('oliver_panel_featured_area',
								 array('title'       => esc_html__('Featured Area', 'oliver'),
									   'description' => esc_html__('Featured Area options.', 'oliver'),
									   'priority'    => 25));
				
				$wp_customize->add_section('oliver_section_featured_area_general',
										   array('title'       => esc_html__('General', 'oliver'),
												 'description' => esc_html__('General options.', 'oliver'),
												 'panel'       => 'oliver_panel_featured_area',
												 'priority'    => 26));
				
				$wp_customize->add_section('oliver_section_featured_area_slider',
										   array('title'       => esc_html__('Slider', 'oliver'),
												 'description' => esc_html__('Go to Widgets section and drag and drop Main Slider widget to Blog/Page Featured Area.', 'oliver'),
												 'panel'       => 'oliver_panel_featured_area',
												 'priority'    => 27));
				
				$wp_customize->add_section('oliver_section_featured_area_link_box',
										   array('title'       => esc_html__('Link Box', 'oliver'),
												 'description' => esc_html__('Go to Widgets section and drag and drop Link Box widgets to Blog/Page Featured Area.', 'oliver'),
												 'panel'       => 'oliver_panel_featured_area',
												 'priority'    => 28));
				
				$wp_customize->add_section('oliver_section_featured_area_intro',
										   array('title'       => esc_html__('Intro', 'oliver'),
												 'description' => esc_html__('Go to Widgets section and drag and drop Intro widget to Blog/Page Featured Area.', 'oliver'),
												 'panel'       => 'oliver_panel_featured_area',
												 'priority'    => 29));
		
		
		$wp_customize->add_section('oliver_section_blog',
								   array('title'       => esc_html__('Blog', 'oliver'),
										 'description' => esc_html__('Blog page options.', 'oliver'),
										 'priority'    => 30));
		
		$wp_customize->add_section('oliver_section_post',
								   array('title'       => esc_html__('Single Post', 'oliver'),
										 'description' => esc_html__('Individual post options.', 'oliver'),
										 'priority'    => 31));
		
		$wp_customize->add_panel('oliver_panel_meta',
								 array('title'       => esc_html__('Meta', 'oliver'),
									   'description' => esc_html__('Meta options.', 'oliver'),
									   'priority'    => 32));
		
				$wp_customize->add_section('oliver_section_meta_style',
										   array('title'       => esc_html__('Style', 'oliver'),
												 'description' => esc_html__('Meta style options.', 'oliver'),
												 'panel'       => 'oliver_panel_meta',
												 'priority'    => 33));
		
				$wp_customize->add_section('oliver_section_meta_blog',
										   array('title'       => esc_html__('Blog Meta', 'oliver'),
												 'description' => esc_html__('Blog meta options.', 'oliver'),
												 'panel'       => 'oliver_panel_meta',
												 'priority'    => 34));
				
				$wp_customize->add_section('oliver_section_meta_post',
										   array('title'       => esc_html__('Single Post Meta', 'oliver'),
												 'description' => esc_html__('Post meta options.', 'oliver'),
												 'panel'       => 'oliver_panel_meta',
												 'priority'    => 35));
		
		$wp_customize->add_section('oliver_section_sidebar',
								   array('title'       => esc_html__('Sidebar', 'oliver'),
										 'description' => esc_html__('Theme sidebar options.', 'oliver'),
										 'priority'    => 36));
		
		$wp_customize->add_section('oliver_section_portfolio',
								   array('title'       => esc_html__('Portfolio', 'oliver'),
										 'description' => esc_html__('Portfolio page options.', 'oliver'),
										 'priority'    => 37));
		
		$wp_customize->add_section('oliver_section_shop',
								   array('title'       => esc_html__('Shop', 'oliver'),
										 'description' => esc_html__('Shop page options.', 'oliver'),
										 'priority'    => 38));
		
		$wp_customize->add_panel('widgets',
								 array('title'       => esc_html__('Widgets', 'oliver'),
									   'description' => esc_html__('Widgets are independent sections of content that can be placed into widgetized areas provided by your theme (commonly called sidebars).', 'oliver'),
									   'priority'    => 99));
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_color_link',
								   array('default'           => '#d2ab74',
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_color_link',
																  array('label'    => esc_html__('Link Color', 'oliver'),
																		'section'  => 'oliver_section_colors',
																		'settings' => 'oliver_setting_color_link')));
		
		
		$wp_customize->add_setting('oliver_setting_color_link_hover',
								   array('default'           => '#c9b69b',
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_color_link_hover',
																  array('label'    => esc_html__('Link Hover Color', 'oliver'),
																		'section'  => 'oliver_section_colors',
																		'settings' => 'oliver_setting_color_link_hover')));
		
		
		$wp_customize->add_setting('oliver_setting_color_body_text',
								   array('default'           => '#222222',
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_color_body_text',
																  array('label'    => esc_html__('Body Text Color', 'oliver'),
																		'section'  => 'oliver_section_colors',
																		'settings' => 'oliver_setting_color_body_text')));
		
		
		$wp_customize->add_setting('oliver_setting_color_body_bg',
								   array('default'           => '#ffffff',
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_color_body_bg',
																  array('label'    => esc_html__('Body Background Color', 'oliver'),
																		'section'  => 'oliver_section_colors',
																		'settings' => 'oliver_setting_color_body_bg')));
		
		
		$wp_customize->add_setting('oliver_setting_color_button_hover_bg',
								   array('default'           => '#333333',
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_color_button_hover_bg',
																  array('label'    => esc_html__('Button Hover Background Color', 'oliver'),
																		'section'  => 'oliver_section_colors',
																		'settings' => 'oliver_setting_color_button_hover_bg')));
		
		
		/* ================================================== */
		
		
		include_once(get_template_directory() . '/admin/fonts.php');
		
		
		$oliver_font_weights = array('100' => '100',
										 '200' => '200',
										 '300' => '300',
										 '400' => '400',
										 '500' => '500',
										 '600' => '600',
										 '700' => '700',
										 '800' => '800',
										 '900' => '900');
		
		
		$oliver_setting_yes_no = array('Yes' => 'Yes',
										   'No'  => 'No');
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_font_text_logo',
								   array('default'           => 'Comfortaa',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_text_logo',
								   array('label'    => esc_html__('Text Logo Font', 'oliver'),
										 'section'  => 'title_tagline',
										 'settings' => 'oliver_setting_font_text_logo',
										 'type'     => 'select',
										 'choices'  => $oliver_fonts));
		
		
		$wp_customize->add_setting('oliver_setting_font_size_text_logo',
								   array('default'           => '48',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_size_text_logo',
								   array('label'    => esc_html__('Text Logo Font Size (px)', 'oliver'),
										 'section'  => 'title_tagline',
										 'settings' => 'oliver_setting_font_size_text_logo',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => 8,
																'max'  => 300,
																'step' => 4)));
		
		
		$wp_customize->add_setting('oliver_setting_font_weight_text_logo',
								   array('default'           => '400',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_weight_text_logo',
								   array('label'    => esc_html__('Text Logo Font Weight', 'oliver'),
										 'section'  => 'title_tagline',
										 'settings' => 'oliver_setting_font_weight_text_logo',
										 'type'     => 'select',
										 'choices'  => $oliver_font_weights));
		
		
		$wp_customize->add_setting('oliver_setting_logo_height',
								   array('default'           => '140',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_logo_height',
								   array('label'    => esc_html__('Image Logo Height (px)', 'oliver'),
										 'section'  => 'title_tagline',
										 'settings' => 'oliver_setting_logo_height',
										 'type'     => 'range',
										 'input_attrs' => array('min'  => 20,
																'max'  => 400,
																'step' => 5)));
		
		
		$wp_customize->add_setting('oliver_setting_logo_height_mobile',
								   array('default'           => '60',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_logo_height_mobile',
								   array('label'    => esc_html__('Image Logo Height Mobile (px)', 'oliver'),
										 'section'  => 'title_tagline',
										 'settings' => 'oliver_setting_logo_height_mobile',
										 'type'     => 'range',
										 'input_attrs' => array('min'  => 30,
																'max'  => 300,
																'step' => 5)));
		
		
		$wp_customize->add_setting('oliver_setting_logo_margin',
								   array('default'           => '70',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_logo_margin',
								   array('label'    => esc_html__('Logo Margin (px)', 'oliver'),
										 'section'  => 'title_tagline',
										 'settings' => 'oliver_setting_logo_margin',
										 'type'     => 'range',
										 'input_attrs' => array('min'  => 0,
																'max'  => 500,
																'step' => 5)));
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_font_h1',
								   array('default'           => 'Coustard',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_h1',
								   array('label'    => esc_html__('Heading Font (H1)', 'oliver'),
										 'section'  => 'oliver_section_fonts',
										 'settings' => 'oliver_setting_font_h1',
										 'type'     => 'select',
										 'choices'  => $oliver_fonts));
		
		
		$wp_customize->add_setting('oliver_setting_font_size_h1',
								   array('default'           => '48',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_size_h1',
								   array('label'    => esc_html__('Heading (H1) Font Size (px)', 'oliver'),
										 'section'  => 'oliver_section_fonts',
										 'settings' => 'oliver_setting_font_size_h1',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => 9,
																'max'  => 200,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_font_weight_h1',
								   array('default'           => '400',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_weight_h1',
								   array('label'    => esc_html__('Heading Font Weight (H1)', 'oliver'),
										 'section'  => 'oliver_section_fonts',
										 'settings' => 'oliver_setting_font_weight_h1',
										 'type'     => 'select',
										 'choices'  => $oliver_font_weights));
		
		
		$wp_customize->add_setting('oliver_setting_text_transform_h1',
								   array('default'           => 'none',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_text_transform_h1',
								   array('label'    => esc_html__('Heading Font Text Transform (H1)', 'oliver'),
										 'section'  => 'oliver_section_fonts',
										 'settings' => 'oliver_setting_text_transform_h1',
										 'type'     => 'select',
										 'choices'  => array('none'      => 'None',
															 'uppercase' => 'Uppercase')));
		
		
		$wp_customize->add_setting('oliver_setting_font_h2_h6',
								   array('default'           => 'Coustard',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_h2_h6',
								   array('label'    => esc_html__('Sub Heading Font (H2-H6)', 'oliver'),
										 'section'  => 'oliver_section_fonts',
										 'settings' => 'oliver_setting_font_h2_h6',
										 'type'     => 'select',
										 'choices'  => $oliver_fonts));
		
		
		$wp_customize->add_setting('oliver_setting_font_weight_h2_h6',
								   array('default'           => '400',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_weight_h2_h6',
								   array('label'    => esc_html__('Sub Heading Font Weight (H2-H6)', 'oliver'),
										 'section'  => 'oliver_section_fonts',
										 'settings' => 'oliver_setting_font_weight_h2_h6',
										 'type'     => 'select',
										 'choices'  => $oliver_font_weights));
		
		
		$wp_customize->add_setting('oliver_setting_text_transform_h2_h6',
								   array('default'           => 'none',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_text_transform_h2_h6',
								   array('label'    => esc_html__('Sub Heading Font Text Transform (H2-H6)', 'oliver'),
										 'section'  => 'oliver_section_fonts',
										 'settings' => 'oliver_setting_text_transform_h2_h6',
										 'type'     => 'select',
										 'choices'  => array('none'      => 'None',
															 'uppercase' => 'Uppercase')));
		
		
		$wp_customize->add_setting('oliver_setting_font_body',
								   array('default'           => 'Karla',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_body',
								   array('label'    => esc_html__('Body Font', 'oliver'),
										 'section'  => 'oliver_section_fonts',
										 'settings' => 'oliver_setting_font_body',
										 'type'     => 'select',
										 'choices'  => $oliver_fonts));
		
		
		$wp_customize->add_setting('oliver_setting_font_size_body',
								   array('default'           => '18',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_size_body',
								   array('label'    => esc_html__('Body Font Size (px)', 'oliver'),
										 'section'  => 'oliver_section_fonts',
										 'settings' => 'oliver_setting_font_size_body',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => 9,
																'max'  => 200,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_body_line_height',
								   array('default'           => '1.7',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_body_line_height',
								   array('label'       => esc_html__('Body Line Height', 'oliver'),
										 'section'     => 'oliver_section_fonts',
										 'settings'    => 'oliver_setting_body_line_height',
										 'type'        => 'number',
										 'input_attrs' => array('min'  => 1,
																'max'  => 3,
																'step' => 0.1)));
		
		
		$wp_customize->add_setting('oliver_setting_font_styles',
								   array('default'           => 'No',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_font_styles',
								   array('label'       => esc_html__('Include All Font Weights (100-900)', 'oliver'),
										 'description' => esc_html__('Bold/italic styles.', 'oliver'),
										 'section'     => 'oliver_section_fonts',
										 'settings'    => 'oliver_setting_font_styles',
										 'type'        => 'select',
										 'choices'     => array('No'  => 'No',
																'Yes' => 'Yes')));
		
		
		$wp_customize->add_setting('oliver_setting_font_char_sets_latin',
								   array('default'   		 => 1,
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport' 		 => 'refresh'));
		
		$wp_customize->add_control('oliver_control_font_char_sets_latin',
								   array('label'    => esc_html__('Latin Characters', 'oliver'),
										 'section'  => 'oliver_section_chars',
										 'settings' => 'oliver_setting_font_char_sets_latin',
										 'type'     => 'checkbox'));
		
		
		$wp_customize->add_setting('oliver_setting_font_char_sets_latin_ext',
								   array('default'   		 => 0,
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport' 		 => 'refresh'));
		
		$wp_customize->add_control('oliver_control_font_char_sets_latin_ext',
								   array('label'    => esc_html__('Latin Characters (extended)', 'oliver'),
										 'section'  => 'oliver_section_chars',
										 'settings' => 'oliver_setting_font_char_sets_latin_ext',
										 'type'     => 'checkbox'));
		
		
		$wp_customize->add_setting('oliver_setting_font_char_sets_cyrillic',
								   array('default'   	     => 0,
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport' 		 => 'refresh'));
		
		$wp_customize->add_control('oliver_control_font_char_sets_cyrillic',
								   array('label'    => esc_html__('Cyrillic Characters', 'oliver'),
										 'section'  => 'oliver_section_chars',
										 'settings' => 'oliver_setting_font_char_sets_cyrillic',
										 'type'     => 'checkbox'));
		
		
		$wp_customize->add_setting('oliver_setting_font_char_sets_cyrillic_ext',
								   array('default'      	 => 0,
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport' 		 => 'refresh'));
		
		$wp_customize->add_control('oliver_control_font_char_sets_cyrillic_ext',
								   array('label'    => esc_html__('Cyrillic Characters (extended)', 'oliver'),
										 'section'  => 'oliver_section_chars',
										 'settings' => 'oliver_setting_font_char_sets_cyrillic_ext',
										 'type'     => 'checkbox'));
		
		
		$wp_customize->add_setting('oliver_setting_font_char_sets_greek',
								   array('default'   		 => 0,
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport' 		 => 'refresh'));
		
		$wp_customize->add_control('oliver_control_font_char_sets_greek',
								   array('label'    => esc_html__('Greek Characters', 'oliver'),
										 'section'  => 'oliver_section_chars',
										 'settings' => 'oliver_setting_font_char_sets_greek',
										 'type'     => 'checkbox'));
		
		
		$wp_customize->add_setting('oliver_setting_font_char_sets_greek_ext',
								   array('default'   		 => 0,
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport' 		 => 'refresh'));
		
		$wp_customize->add_control('oliver_control_font_char_sets_greek_ext',
								   array('label'    => esc_html__('Greek Characters (extended)', 'oliver'),
										 'section'  => 'oliver_section_chars',
										 'settings' => 'oliver_setting_font_char_sets_greek_ext',
										 'type'     => 'checkbox'));
		
		
		$wp_customize->add_setting('oliver_setting_font_char_sets_vietnamese',
								   array('default'   		 => 0,
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport' 		 => 'refresh'));
		
		$wp_customize->add_control('oliver_control_font_char_sets_vietnamese',
								   array('label'    => esc_html__('Vietnamese Characters', 'oliver'),
										 'section'  => 'oliver_section_chars',
										 'settings' => 'oliver_setting_font_char_sets_vietnamese',
										 'type'     => 'checkbox'));
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_body_layout',
								   array('default'           => 'is-body-full-width',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_body_layout',
								   array('label'    => esc_html__('Body Layout', 'oliver'),
										 'section'  => 'oliver_section_layout',
										 'settings' => 'oliver_setting_body_layout',
										 'type'     => 'select',
										 'choices'  => array('is-body-full-width' => 'Full-width',
															 'is-body-boxed' 	  => 'Boxed',
															 'is-middle-boxed' 	  => 'Middle Boxed')));
		
		
		$wp_customize->add_setting('oliver_setting_body_top_bottom_margin',
								   array('default'           => '0',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_body_top_bottom_margin',
								   array('label'       => esc_html__('Body Top-Bottom Margin', 'oliver'),
										 'section'     => 'oliver_section_layout',
										 'settings'    => 'oliver_setting_body_top_bottom_margin',
										 'type'        => 'range',
										 'input_attrs' => array('min'  => 0,
																'max'  => 400,
																'step' => 20)));
		
		
		$wp_customize->add_setting('oliver_setting_content_width',
								   array('default'           => '1060',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_content_width',
								   array('label'       => esc_html__('Content Width (px)', 'oliver'),
										 'section'     => 'oliver_section_layout',
										 'settings'    => 'oliver_setting_content_width',
										 'type'        => 'number',
										 'input_attrs' => array('min'  => 500,
																'max'  => 5000,
																'step' => 10)));
		
		
		$wp_customize->add_setting('oliver_setting_page_post_content_width',
								   array('default'           => '740',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_page_post_content_width',
								   array('label'       => esc_html__('Page/Post Content Width (px)', 'oliver'),
										 'section'     => 'oliver_section_layout',
										 'settings'    => 'oliver_setting_page_post_content_width',
										 'type'        => 'number',
										 'input_attrs' => array('min'  => 320,
																'max'  => 2000,
																'step' => 10)));
		
		
		$wp_customize->add_setting('oliver_setting_mobile_zoom',
								   array('default'           => 'Yes',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_mobile_zoom',
								   array('label'    => esc_html__('Mobile Zoom', 'oliver'),
										 'section'  => 'oliver_section_layout',
										 'settings' => 'oliver_setting_mobile_zoom',
										 'type'     => 'select',
										 'choices'  => $oliver_setting_yes_no));
		
		
		$wp_customize->add_setting('oliver_setting_smooth_scroll',
								   array('default'           => 'no',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_smooth_scroll',
								   array('label'    => esc_html__('Smooth Scroll', 'oliver'),
										 'section'  => 'oliver_section_layout',
										 'settings' => 'oliver_setting_smooth_scroll',
										 'type'     => 'select',
										 'choices'  => array('no'  => 'No',
															 'yes' => 'Yes')));
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_header_layout',
								   array('default'           => 'is-menu-bottom is-menu-bar',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_header_layout',
								   array('label'    => esc_html__('Header Layout', 'oliver'),
										 'section'  => 'oliver_section_header_general',
										 'settings' => 'oliver_setting_header_layout',
										 'type'     => 'select',
										 'choices'  => array('is-menu-top is-menu-bar'    => 'Menu Top',
															 'is-menu-bottom is-menu-bar' => 'Menu Bottom',
															 'is-header-row'              => 'Header One Row',
															 'is-header-small'            => 'Header Small')));
		
		
		$wp_customize->add_setting('oliver_setting_header_width',
								   array('default'           => 'is-header-fixed-width',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_header_width',
								   array('label'    => esc_html__('Header Width', 'oliver'),
										 'section'  => 'oliver_section_header_general',
										 'settings' => 'oliver_setting_header_width',
										 'type'     => 'select',
										 'choices'  => array('is-header-full-width'        => 'Full',
															 'is-header-fixed-width'       => 'Fixed',
															 'is-header-full-with-margins' => 'Full with margins')));
		
		
		$wp_customize->add_setting('oliver_setting_color_header_bg',
								   array('default'           => '#ffffff',
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_color_header_bg',
																  array('label'    => esc_html__('Header Background Color', 'oliver'),
																		'section'  => 'oliver_section_header_general',
																		'settings' => 'oliver_setting_color_header_bg')));
		
		
		$wp_customize->add_setting('oliver_setting_header_bg_img',
								   array('default'           => "",
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,
																  'oliver_control_header_bg_img',
																  array('label'       => esc_html__('Header Background Image', 'oliver'),
																		'description' => esc_html__('Upload an image or choose from your media library.', 'oliver'),
																		'section'     => 'oliver_section_header_general',
																		'settings'    => 'oliver_setting_header_bg_img')));
		
		
		$wp_customize->add_setting('oliver_setting_header_parallax_effect',
								   array('default'           => 'is-header-parallax-no',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_header_parallax_effect',
								   array('label'    => esc_html__('Header Parallax Effect', 'oliver'),
										 'section'  => 'oliver_section_header_general',
										 'settings' => 'oliver_setting_header_parallax_effect',
										 'type'     => 'select',
										 'choices'  => array('is-header-parallax-no' => 'No',
															 'is-header-parallax' 	 => 'Yes')));
		
		
		$wp_customize->add_setting('oliver_setting_header_bg_video',
								   array('default' 			 => "",
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport' 		 => 'refresh'));
		
		$wp_customize->add_control('oliver_control_header_bg_video',
								   array('label'       => esc_html__('Header Background Video', 'oliver'),
										 'description' => esc_html__('YouTube, Vimeo page url.', 'oliver'),
										 'section'     => 'oliver_section_header_general',
										 'settings'    => 'oliver_setting_header_bg_video',
										 'type'        => 'text'));
		
		
		$wp_customize->add_setting('oliver_setting_header_mask_style',
								   array('default'           => 'none',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_header_mask_style',
								   array('label'    => esc_html__('Header Mask Style', 'oliver'),
										 'section'  => 'oliver_section_header_general',
										 'settings' => 'oliver_setting_header_mask_style',
										 'type'     => 'select',
										 'choices'  => array('none'    	  => 'None',
															 'solid'      => 'Solid Color',
															 'vertical'   => 'Vertical Gradient',
															 'horizontal' => 'Horizontal Gradient',
															 'radial' 	  => 'Radial Gradient')));
		
		
		$wp_customize->add_setting('oliver_setting_color_header_mask_1',
								   array('default'           => "",
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_color_header_mask_1',
																  array('label'    => esc_html__('Header Mask Color 1', 'oliver'),
																		'section'  => 'oliver_section_header_general',
																		'settings' => 'oliver_setting_color_header_mask_1')));
		
		
		$wp_customize->add_setting('oliver_setting_color_header_mask_2',
								   array('default'           => "",
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_color_header_mask_2',
																  array('label'    => esc_html__('Header Mask Color 2', 'oliver'),
																		'section'  => 'oliver_section_header_general',
																		'settings' => 'oliver_setting_color_header_mask_2')));
		
		
		$wp_customize->add_setting('oliver_setting_header_mask_opacity',
								   array('default'           => '0.4',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_header_mask_opacity',
								   array('label'       => esc_html__('Header Mask Opacity', 'oliver'),
										 'section'     => 'oliver_section_header_general',
										 'settings'    => 'oliver_setting_header_mask_opacity',
										 'type'        => 'range',
										 'input_attrs' => array('min'  => 0.1,
																'max'  => 1.0,
																'step' => 0.1)));
		
		
		$wp_customize->add_setting('oliver_setting_header_text_color',
								   array('default'           => 'is-header-light',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_header_text_color',
								   array('label'    => esc_html__('Header Text Color', 'oliver'),
										 'section'  => 'oliver_section_header_general',
										 'settings' => 'oliver_setting_header_text_color',
										 'type'     => 'select',
										 'choices'  => array('is-header-light' => 'Dark',
															 'is-header-dark'  => 'Light')));
		
		
		$wp_customize->add_setting('oliver_setting_header_search',
								   array('default'           => 'Yes',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_header_search',
								   array('label'    => esc_html__('Header Search', 'oliver'),
										 'section'  => 'oliver_section_header_general',
										 'settings' => 'oliver_setting_header_search',
										 'type'     => 'select',
										 'choices'  => $oliver_setting_yes_no));
		
		
		$wp_customize->add_setting('oliver_setting_menu_behaviour',
								   array('default'       	 => 'is-menu-sticky is-menu-smart-sticky',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_menu_behaviour',
								   array('label'    => esc_html__('Menu Behaviour', 'oliver'),
										 'section'  => 'oliver_section_header_menu',
										 'settings' => 'oliver_setting_menu_behaviour',
										 'type'     => 'select',
										 'choices'  => array('is-menu-sticky' 					   => 'Sticky',
														     'is-menu-sticky is-menu-smart-sticky' => 'Smart Sticky',
														     'is-menu-static' 					   => 'Static')));
		
		
		$wp_customize->add_setting('oliver_setting_menu_width',
								   array('default'       	 => 'is-menu-fixed-width',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_menu_width',
								   array('label'    => esc_html__('Menu Width', 'oliver'),
										 'section'  => 'oliver_section_header_menu',
										 'settings' => 'oliver_setting_menu_width',
										 'type'     => 'select',
										 'choices'  => array('is-menu-fixed-width' => 'Fixed',
														     'is-menu-fixed-bg'    => 'Fixed Bg',
														     'is-menu-full'        => 'Full')));
		
		
		$wp_customize->add_setting('oliver_setting_header_menu_align',
								   array('default'           => 'is-menu-align-center',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_header_menu_align',
								   array('label'    => esc_html__('Menu Align', 'oliver'),
										 'section'  => 'oliver_section_header_menu',
										 'settings' => 'oliver_setting_header_menu_align',
										 'type'     => 'select',
										 'choices'  => array('is-menu-align-center' => 'Center',
															 'is-menu-align-left'   => 'Left',
															 'is-menu-align-right'  => 'Right')));
		
		
		$wp_customize->add_setting('oliver_setting_header_menu_style',
								   array('default'           => 'is-menu-light',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_header_menu_style',
								   array('label'    => esc_html__('Menu Text Color', 'oliver'),
										 'section'  => 'oliver_section_header_menu',
										 'settings' => 'oliver_setting_header_menu_style',
										 'type'     => 'select',
										 'choices'  => array('is-menu-light' => 'Dark',
															 'is-menu-dark'  => 'Light')));
		
		
		$wp_customize->add_setting('oliver_setting_color_menu_bg',
								   array('default'           => '#ffffff',
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_color_menu_bg',
																  array('label'    => esc_html__('Menu Background Color', 'oliver'),
																		'section'  => 'oliver_section_header_menu',
																		'settings' => 'oliver_setting_color_menu_bg')));
		
		
		$wp_customize->add_setting('oliver_setting_color_menu_link_hover',
								   array('default'           => "",
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_color_menu_link_hover',
																  array('label'    => esc_html__('Menu Link Hover Color', 'oliver'),
																		'section'  => 'oliver_section_header_menu',
																		'settings' => 'oliver_setting_color_menu_link_hover')));
		
		
		$wp_customize->add_setting('oliver_setting_font_menu',
								   array('default'           => 'Karla',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_menu',
								   array('label'       => esc_html__('Menu Font', 'oliver'),
										 'description' => esc_html__('Also for buttons and labels.', 'oliver'),
										 'section'     => 'oliver_section_header_menu',
										 'settings'    => 'oliver_setting_font_menu',
										 'type'        => 'select',
										 'choices'     => $oliver_fonts));
		
		
		$wp_customize->add_setting('oliver_setting_font_size_nav_menu',
								   array('default'           => '12',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_size_nav_menu',
								   array('label'    => esc_html__('Menu Font Size (px)', 'oliver'),
										 'section'  => 'oliver_section_header_menu',
										 'settings' => 'oliver_setting_font_size_nav_menu',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => 9,
																'max'  => 200,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_font_weight_nav_menu',
								   array('default'           => '700',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_weight_nav_menu',
								   array('label'    => esc_html__('Menu Font Weight', 'oliver'),
										 'section'  => 'oliver_section_header_menu',
										 'settings' => 'oliver_setting_font_weight_nav_menu',
										 'type'     => 'select',
										 'choices'  => $oliver_font_weights));
		
		
		$wp_customize->add_setting('oliver_setting_letter_spacing_nav_menu',
								   array('default'           => '1',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_letter_spacing_nav_menu',
								   array('label'    => esc_html__('Menu Letter Spacing (px)', 'oliver'),
										 'section'  => 'oliver_section_header_menu',
										 'settings' => 'oliver_setting_letter_spacing_nav_menu',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => -5,
																'max'  => 20,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_header_sub_menu_style',
								   array('default'           => 'is-submenu-dark',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_header_sub_menu_style',
								   array('label'    => esc_html__('Sub Menu Style', 'oliver'),
										 'section'  => 'oliver_section_header_menu',
										 'settings' => 'oliver_setting_header_sub_menu_style',
										 'type'     => 'select',
										 'choices'  => array('is-submenu-light'        => 'Light',
															 'is-submenu-light-border' => 'Light Border',
															 'is-submenu-dark'         => 'Dark')));
		
		
		$wp_customize->add_setting('oliver_setting_header_sub_menu_align',
								   array('default'           => 'is-submenu-align-center',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_header_sub_menu_align',
								   array('label'    => esc_html__('Sub Menu Align', 'oliver'),
										 'section'  => 'oliver_section_header_menu',
										 'settings' => 'oliver_setting_header_sub_menu_align',
										 'type'     => 'select',
										 'choices'  => array('is-submenu-align-center' => 'Center',
															 'is-submenu-align-left'   => 'Left',
															 'is-submenu-align-right'  => 'Right')));
		
		
		$wp_customize->add_setting('oliver_setting_font_size_nav_sub_menu',
								   array('default'           => '11',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_size_nav_sub_menu',
								   array('label'    => esc_html__('Sub Menu Font Size (px)', 'oliver'),
										 'section'  => 'oliver_section_header_menu',
										 'settings' => 'oliver_setting_font_size_nav_sub_menu',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => 9,
																'max'  => 200,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_font_weight_nav_sub_menu',
								   array('default'           => '400',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_weight_nav_sub_menu',
								   array('label'    => esc_html__('Sub Menu Font Weight', 'oliver'),
										 'section'  => 'oliver_section_header_menu',
										 'settings' => 'oliver_setting_font_weight_nav_sub_menu',
										 'type'     => 'select',
										 'choices'  => $oliver_font_weights));
		
		
		$wp_customize->add_setting('oliver_setting_letter_spacing_nav_sub_menu',
								   array('default'           => '1',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_letter_spacing_nav_sub_menu',
								   array('label'    => esc_html__('Sub Menu Letter Spacing (px)', 'oliver'),
										 'section'  => 'oliver_section_header_menu',
										 'settings' => 'oliver_setting_letter_spacing_nav_sub_menu',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => -5,
																'max'  => 20,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_header_menu_text_transform',
								   array('default'           => 'is-menu-uppercase',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_header_menu_text_transform',
								   array('label'    => esc_html__('Menu Text Transform', 'oliver'),
										 'section'  => 'oliver_section_header_menu',
										 'settings' => 'oliver_setting_header_menu_text_transform',
										 'type'     => 'select',
										 'choices'  => array('is-menu-uppercase'      => 'Uppercase',
															 'is-menu-none-uppercase' => 'None')));
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_footer_layout',
								   array('default'           => 'is-footer-boxed',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_footer_layout',
								   array('label'    => esc_html__('Footer Layout', 'oliver'),
										 'section'  => 'oliver_section_footer',
										 'settings' => 'oliver_setting_footer_layout',
										 'type'     => 'select',
										 'choices'  => array('is-footer-full-width' => 'Full-width',
															 'is-footer-boxed'  	=> 'Boxed')));
		
		
		$wp_customize->add_setting('oliver_setting_footer_columns',
								   array('default'           => '4',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_footer_columns',
								   array('label'       => esc_html__('Footer Columns', 'oliver'),
										 'description' => esc_html__('Footer widget areas.', 'oliver'),
										 'section'     => 'oliver_section_footer',
										 'settings'    => 'oliver_setting_footer_columns',
										 'type'        => 'select',
										 'choices'     => array('4' => '4 Columns',
																'3' => '3 Columns')));
		
		
		$wp_customize->add_setting('oliver_setting_color_footer_bg',
								   array('default'           => "",
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_color_footer_bg',
																  array('label'    => esc_html__('Footer Background Color', 'oliver'),
																		'section'  => 'oliver_section_footer',
																		'settings' => 'oliver_setting_color_footer_bg')));
		
		
		$wp_customize->add_setting('oliver_setting_footer_subscribe_style',
								   array('default'           => 'is-footer-subscribe-light',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_footer_subscribe_style',
								   array('label'    => esc_html__('Footer Subscribe Style', 'oliver'),
										 'section'  => 'oliver_section_footer',
										 'settings' => 'oliver_setting_footer_subscribe_style',
										 'type'     => 'select',
										 'choices'  => array('is-footer-subscribe-light' => 'Light',
															 'is-footer-subscribe-dark'  => 'Dark')));
		
		
		$wp_customize->add_setting('oliver_setting_color_footer_subscribe_bg',
								   array('default'           => '#ffffff',
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_color_footer_subscribe_bg',
																  array('label'    => esc_html__('Footer Subscribe Background Color', 'oliver'),
																		'section'  => 'oliver_section_footer',
																		'settings' => 'oliver_setting_color_footer_subscribe_bg')));
		
		
		$wp_customize->add_setting('oliver_setting_color_copyright_bar_bg',
								   array('default'           => "",
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_color_copyright_bar_bg',
																  array('label'    => esc_html__('Copyright Bar Background Color', 'oliver'),
																		'section'  => 'oliver_section_footer',
																		'settings' => 'oliver_setting_color_copyright_bar_bg')));
		
		
		$wp_customize->add_setting('oliver_setting_color_copyright_bar_text',
								   array('default'           => "",
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_color_copyright_bar_text',
																  array('label'    => esc_html__('Copyright Bar Text Color', 'oliver'),
																		'section'  => 'oliver_section_footer',
																		'settings' => 'oliver_setting_color_copyright_bar_text')));
		
		
		$wp_customize->add_setting('oliver_setting_footer_widget_text_align',
								   array('default'           => 'is-footer-widgets-align-left',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_footer_widget_text_align',
								   array('label'    => esc_html__('Footer Widgets Text Align', 'oliver'),
										 'section'  => 'oliver_section_footer',
										 'settings' => 'oliver_setting_footer_widget_text_align',
										 'type'     => 'select',
										 'choices'  => array('is-footer-widgets-align-left'   => 'Left',
															 'is-footer-widgets-align-center' => 'Center')));
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_sidebar_blog',
								   array('default'           => 'No',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_sidebar_blog',
								   array('label'       => esc_html__('Blog Sidebar', 'oliver'),
										 'description' => esc_html__('Activate sidebar area for blog page.', 'oliver'),
										 'section'     => 'oliver_section_sidebar',
										 'settings'    => 'oliver_setting_sidebar_blog',
										 'type'        => 'select',
										 'choices'     => $oliver_setting_yes_no));
		
		
		$wp_customize->add_setting('oliver_setting_sidebar_post',
								   array('default'           => 'No',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_sidebar_post',
								   array('label'       => esc_html__('Post Sidebar', 'oliver'),
										 'description' => esc_html__('Activate sidebar area for single posts.', 'oliver'),
										 'section'     => 'oliver_section_sidebar',
										 'settings'    => 'oliver_setting_sidebar_post',
										 'type'        => 'select',
										 'choices'     => $oliver_setting_yes_no));
		
		
		$wp_customize->add_setting('oliver_setting_sidebar_portfolio_category',
								   array('default'           => 'No',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_sidebar_portfolio_category',
								   array('label'       => esc_html__('Portfolio Category Sidebar', 'oliver'),
										 'description' => esc_html__('Activate sidebar area for portfolio category pages.', 'oliver'),
										 'section'     => 'oliver_section_sidebar',
										 'settings'    => 'oliver_setting_sidebar_portfolio_category',
										 'type'        => 'select',
										 'choices'     => $oliver_setting_yes_no));
		
		
		$wp_customize->add_setting('oliver_setting_sidebar_portfolio_post',
								   array('default'           => 'No',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_sidebar_portfolio_post',
								   array('label'       => esc_html__('Portfolio Post Sidebar', 'oliver'),
										 'description' => esc_html__('Activate sidebar area for single portfolio posts.', 'oliver'),
										 'section'     => 'oliver_section_sidebar',
										 'settings'    => 'oliver_setting_sidebar_portfolio_post',
										 'type'        => 'select',
										 'choices'     => $oliver_setting_yes_no));
		
		
		$wp_customize->add_setting('oliver_setting_sidebar_shop',
								   array('default'           => 'No',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_sidebar_shop',
								   array('label'       => esc_html__('Shop Sidebar', 'oliver'),
										 'description' => esc_html__('Activate sidebar area for shop page. (for WooCommerce plugin)', 'oliver'),
										 'section'     => 'oliver_section_sidebar',
										 'settings'    => 'oliver_setting_sidebar_shop',
										 'type'        => 'select',
										 'choices'     => $oliver_setting_yes_no));
		
		
		$wp_customize->add_setting('oliver_setting_sidebar_product_category',
								   array('default'           => 'No',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_sidebar_product_category',
								   array('label'       => esc_html__('Product Category Sidebar', 'oliver'),
										 'description' => esc_html__('Activate sidebar area for shop categories. (for WooCommerce plugin)', 'oliver'),
										 'section'     => 'oliver_section_sidebar',
										 'settings'    => 'oliver_setting_sidebar_product_category',
										 'type'        => 'select',
										 'choices'     => $oliver_setting_yes_no));
		
		
		$wp_customize->add_setting('oliver_setting_sidebar_single_product',
								   array('default'           => 'No',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_sidebar_single_product',
								   array('label'       => esc_html__('Single Product Sidebar', 'oliver'),
										 'description' => esc_html__('Activate sidebar area for individual product page. (for WooCommerce plugin)', 'oliver'),
										 'section'     => 'oliver_section_sidebar',
										 'settings'    => 'oliver_setting_sidebar_single_product',
										 'type'        => 'select',
										 'choices'     => $oliver_setting_yes_no));
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_sidebar_position',
								   array('default'           => 'is-sidebar-right',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_sidebar_position',
								   array('label'    => esc_html__('Sidebar Position', 'oliver'),
										 'section'  => 'oliver_section_sidebar',
										 'settings' => 'oliver_setting_sidebar_position',
										 'type'     => 'select',
										 'choices'  => array('is-sidebar-right' => 'Right',
															 'is-sidebar-left'  => 'Left')));
		
		
		$wp_customize->add_setting('oliver_setting_sidebar_sticky',
								   array('default'           => 'is-sidebar-sticky',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_sidebar_sticky',
								   array('label'    => esc_html__('Sticky Sidebar', 'oliver'),
										 'section'  => 'oliver_section_sidebar',
										 'settings' => 'oliver_setting_sidebar_sticky',
										 'type'     => 'select',
										 'choices'  => array('is-sidebar-sticky' 	=> 'Yes',
															 'is-sidebar-sticky-no' => 'No')));
		
		
		$wp_customize->add_setting('oliver_setting_font_size_sidebar',
								   array('default'           => '14',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_size_sidebar',
								   array('label'    => esc_html__('Sidebar Font Size (px)', 'oliver'),
										 'section'  => 'oliver_section_sidebar',
										 'settings' => 'oliver_setting_font_size_sidebar',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => 9,
																'max'  => 200,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_sidebar_widget_text_align',
								   array('default'           => 'is-sidebar-align-left',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_sidebar_widget_text_align',
								   array('label'    => esc_html__('Sidebar Widgets Text Align', 'oliver'),
										 'section'  => 'oliver_section_sidebar',
										 'settings' => 'oliver_setting_sidebar_widget_text_align',
										 'type'     => 'select',
										 'choices'  => array('is-sidebar-align-left'   => 'Left',
															 'is-sidebar-align-center' => 'Center')));
		
		
		$wp_customize->add_setting('oliver_setting_sidebar_widget_title_align',
								   array('default'           => 'is-widget-title-align-left',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_sidebar_widget_title_align',
								   array('label'    => esc_html__('Widget Title Align', 'oliver'),
										 'section'  => 'oliver_section_sidebar',
										 'settings' => 'oliver_setting_sidebar_widget_title_align',
										 'type'     => 'select',
										 'choices'  => array('is-widget-title-align-left'   => 'Left',
															 'is-widget-title-align-center' => 'Center')));
		
		
		$wp_customize->add_setting('oliver_setting_sidebar_widget_title_style',
								   array('default'           => 'is-widget-underline',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_sidebar_widget_title_style',
								   array('label'    => esc_html__('Widget Title Style', 'oliver'),
										 'section'  => 'oliver_section_sidebar',
										 'settings' => 'oliver_setting_sidebar_widget_title_style',
										 'type'     => 'select',
										 'choices'  => array('is-widget-minimal'             => 'Minimal',
															 'is-widget-ribbon'              => 'Ribbon',
															 'is-widget-border'              => 'Border',
															 'is-widget-border-arrow'        => 'Border Arrow',
															 'is-widget-solid'               => 'Solid',
															 'is-widget-solid-arrow'         => 'Solid Arrow',
															 'is-widget-underline'           => 'Underline',
															 'is-widget-bottomline'          => 'Bottomline',
															 'is-widget-first-letter-border' => 'First Letter Border',
															 'is-widget-first-letter-solid'  => 'First Letter Solid',
															 'is-widget-line-cut'            => 'Line Cut',
															 'is-widget-line-cut-center'     => 'Line Cut Center')));
		
		
		$wp_customize->add_setting('oliver_setting_font_widget_title',
								   array('default'           => 'Karla',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_widget_title',
								   array('label'    => esc_html__('Widget Title Font', 'oliver'),
										 'section'  => 'oliver_section_sidebar',
										 'settings' => 'oliver_setting_font_widget_title',
										 'type'     => 'select',
										 'choices'  => $oliver_fonts));
		
		
		$wp_customize->add_setting('oliver_setting_font_size_sidebar_widget_title',
								   array('default'           => '12',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_size_sidebar_widget_title',
								   array('label'    => esc_html__('Widget Title Font Size (px)', 'oliver'),
										 'section'  => 'oliver_section_sidebar',
										 'settings' => 'oliver_setting_font_size_sidebar_widget_title',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => 9,
																'max'  => 200,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_font_weight_sidebar_widget_title',
								   array('default'           => '700',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_weight_sidebar_widget_title',
								   array('label'    => esc_html__('Widget Title Font Weight', 'oliver'),
										 'section'  => 'oliver_section_sidebar',
										 'settings' => 'oliver_setting_font_weight_sidebar_widget_title',
										 'type'     => 'select',
										 'choices'  => $oliver_font_weights));
		
		
		$wp_customize->add_setting('oliver_setting_letter_spacing_sidebar_widget_title',
								   array('default'           => '6',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_letter_spacing_sidebar_widget_title',
								   array('label'    => esc_html__('Widget Title Letter Spacing (px)', 'oliver'),
										 'section'  => 'oliver_section_sidebar',
										 'settings' => 'oliver_setting_letter_spacing_sidebar_widget_title',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => -5,
																'max'  => 20,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_color_widget_witle_bg_border',
								   array('default'           => "",
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_color_widget_witle_bg_border',
																  array('label'    => esc_html__('Widget Title Bg/Border Color', 'oliver'),
																		'section'  => 'oliver_section_sidebar',
																		'settings' => 'oliver_setting_color_widget_witle_bg_border')));
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_portfolio_page_layout',
								   array('default'           => 'layout-medium',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_portfolio_page_layout',
								   array('label' 	   => esc_html__('Portfolio Category Layout', 'oliver'),
										 'description' => esc_html__('For portfolio category pages.', 'oliver'),
										 'section' 	   => 'oliver_section_portfolio',
										 'settings'    => 'oliver_setting_portfolio_page_layout',
										 'type' 	   => 'select',
										 'choices' 	   => array('layout-medium' => 'Default',
																'layout-fixed'  => 'Narrow',
																'layout-full' 	=> 'Full Width')));
		
		
		$wp_customize->add_setting('oliver_setting_portfolio_page_grid_type',
								   array('default'           => 'masonry',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_portfolio_page_grid_type',
								   array('label'    => esc_html__('Grid Type', 'oliver'),
										 'section'  => 'oliver_section_portfolio',
										 'settings' => 'oliver_setting_portfolio_page_grid_type',
										 'type'     => 'select',
										 'choices'  => array('masonry' 		  => 'Masonry',
															 'fitRows_square' => 'Fit Rows - (Square)',
															 'fitRows_wide'   => 'Fit Rows - (Wide)')));
		
		
		$wp_customize->add_setting('oliver_setting_portfolio_page_post_width',
								   array('default'           => '320',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_portfolio_page_post_width',
								   array('label' 	   => esc_html__('Grid Post Width (px)', 'oliver'),
										 'section' 	   => 'oliver_section_portfolio',
										 'settings'    => 'oliver_setting_portfolio_page_post_width',
										 'type' 	   => 'number',
										 'input_attrs' => array('min'  => 120,
																'max'  => 1200,
																'step' => 10)));
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_shop_grid_item_width',
								   array('default'           => '320',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_shop_grid_item_width',
								   array('label' 	   => esc_html__('Grid Item Width (px)', 'oliver'),
										 'description' => esc_html__('Default: 320', 'oliver'),
										 'section' 	   => 'oliver_section_shop',
										 'settings'    => 'oliver_setting_shop_grid_item_width',
										 'type' 	   => 'number',
										 'input_attrs' => array('min'  => 100,
																'max'  => 700,
																'step' => 10)));
		
		
		$wp_customize->add_setting(
			'oliver_setting_products_per_page',
			array(
				'default'           => 9,
				'sanitize_callback' => 'oliver_sanitize',
				'transport'         => 'refresh'
			)
		);
		
		$wp_customize->add_control(
			'oliver_control_products_per_page',
			array(
				'label'       => esc_html__('Products Per Page', 'oliver'),
				'description' => esc_html__('Number of products displayed per page.', 'oliver'),
				'section'     => 'oliver_section_shop',
				'settings'    => 'oliver_setting_products_per_page',
				'type'        => 'number',
				'input_attrs' => array(
					'min'  => 1,
					'max'  => 100,
					'step' => 1
				)
			)
		);
		
		
		$wp_customize->add_setting(
			'oliver_setting_related_products_count',
			array(
				'default'           => 3,
				'sanitize_callback' => 'oliver_sanitize',
				'transport'         => 'refresh'
			)
		);
		
		$wp_customize->add_control(
			'oliver_control_related_products_count',
			array(
				'label'       => esc_html__('Related Products Count', 'oliver'),
				'description' => esc_html__('Number of products to show.', 'oliver'),
				'section'     => 'oliver_section_shop',
				'settings'    => 'oliver_setting_related_products_count',
				'type'        => 'number',
				'input_attrs' => array(
					'min'  => 1,
					'max'  => 15,
					'step' => 1
				)
			)
		);
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_feat_area_width',
								   array('default'           => 'is-featured-area-fixed',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_feat_area_width',
								   array('label'    => esc_html__('Featured Area Width', 'oliver'),
										 'section'  => 'oliver_section_featured_area_general',
										 'settings' => 'oliver_setting_feat_area_width',
										 'type'     => 'select',
										 'choices'  => array('is-featured-area-fixed'        => 'Fixed',
															 'is-featured-area-full'         => 'Full',
															 'is-featured-area-full-margins' => 'Full With Margins')));
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_main_slider_nav_position',
								   array('default'           => 'is-slider-buttons-center-margin',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_main_slider_nav_position',
								   array('label'    => esc_html__('Slider Nav Position', 'oliver'),
										 'section'  => 'oliver_section_featured_area_slider',
										 'settings' => 'oliver_setting_main_slider_nav_position',
										 'type'     => 'select',
										 'choices'  => array('is-slider-buttons-stick-to-edges' => 'Stick To Edges',
															 'is-slider-buttons-center-margin'  => 'Center Margin')));
		
		
		$wp_customize->add_setting('oliver_setting_main_slider_nav_shape',
								   array('default'           => 'is-slider-buttons-rounded',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_main_slider_nav_shape',
								   array('label'    => esc_html__('Slider Nav Shape', 'oliver'),
										 'section'  => 'oliver_section_featured_area_slider',
										 'settings' => 'oliver_setting_main_slider_nav_shape',
										 'type'     => 'select',
										 'choices'  => array('is-slider-buttons-sharp-edges' => 'Sharp Edges',
															 'is-slider-buttons-rounded'     => 'Rounded')));
		
		
		$wp_customize->add_setting('oliver_setting_main_slider_nav_style',
								   array('default'           => 'is-slider-buttons-dark',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_main_slider_nav_style',
								   array('label'    => esc_html__('Slider Nav Style', 'oliver'),
										 'section'  => 'oliver_section_featured_area_slider',
										 'settings' => 'oliver_setting_main_slider_nav_style',
										 'type'     => 'select',
										 'choices'  => array('is-slider-buttons-dark'   => 'Dark',
															 'is-slider-buttons-light'  => 'Light',
															 'is-slider-buttons-border' => 'Border')));
		
		
		$wp_customize->add_setting('oliver_setting_main_slider_title_style',
								   array('default'           => 'is-slider-title-default',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_main_slider_title_style',
								   array('label'    => esc_html__('Slider Title Style', 'oliver'),
										 'section'  => 'oliver_section_featured_area_slider',
										 'settings' => 'oliver_setting_main_slider_title_style',
										 'type'     => 'select',
										 'choices'  => array('is-slider-title-default'        				 => 'Default',
															 'is-slider-title-label' 		  				 => 'Label',
															 'is-slider-title-label is-slider-title-rotated' => 'Label Rotated',
															 'is-slider-title-inline-borders' 				 => 'Inline Borders',
															 'is-slider-title-stamp'         				 => 'Stamp',
															 'is-slider-title-border-bottom' 				 => 'Border Bottom',
															 'is-slider-title-3d-shadow' 					 => '3D Shadow',
															 'is-slider-title-3d-hard-shadow' 				 => '3D Hard Shadow',
															 'is-slider-title-dark-shadow' 					 => 'Dark Shadow',
															 'is-slider-title-retro-shadow' 				 => 'Retro Shadow',
															 'is-slider-title-comic-shadow' 				 => 'Comic Shadow',
															 'is-slider-title-futurist-shadow' 				 => 'Futurist Shadow')));
		
		
		$wp_customize->add_setting('oliver_setting_main_slider_parallax_effect',
								   array('default'           => 'is-slider-parallax-no',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_main_slider_parallax_effect',
								   array('label'    => esc_html__('Slider Parallax Effect', 'oliver'),
										 'section'  => 'oliver_section_featured_area_slider',
										 'settings' => 'oliver_setting_main_slider_parallax_effect',
										 'type'     => 'select',
										 'choices'  => array('is-slider-parallax-no' => 'No',
															 'is-slider-parallax' 	 => 'Yes')));
		
		
		$wp_customize->add_setting('oliver_setting_font_slider_title',
								   array('default'           => 'Coustard',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_slider_title',
								   array('label'    => esc_html__('Slider Title Font', 'oliver'),
										 'section'  => 'oliver_section_featured_area_slider',
										 'settings' => 'oliver_setting_font_slider_title',
										 'type'     => 'select',
										 'choices'  => $oliver_fonts));
		
		
		$wp_customize->add_setting('oliver_setting_font_weight_slider_title',
								   array('default'           => '400',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_weight_slider_title',
								   array('label'    => esc_html__('Slider Title Font Weight', 'oliver'),
										 'section'  => 'oliver_section_featured_area_slider',
										 'settings' => 'oliver_setting_font_weight_slider_title',
										 'type'     => 'select',
										 'choices'  => $oliver_font_weights));
		
		
		$wp_customize->add_setting('oliver_setting_letter_spacing_main_slider_title',
								   array('default'           => '0',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_letter_spacing_main_slider_title',
								   array('label'       => esc_html__('Slider Title Letter Spacing (px)', 'oliver'),
										 'section'     => 'oliver_section_featured_area_slider',
										 'settings'    => 'oliver_setting_letter_spacing_main_slider_title',
										 'type'        => 'number',
										 'input_attrs' => array('min'  => -5,
																'max'  => 20,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_font_title_ratio',
								   array('default'           => '0.3',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_font_title_ratio',
								   array('label'       => esc_html__('Slider Title Text Ratio', 'oliver'),
										 'section'     => 'oliver_section_featured_area_slider',
										 'settings'    => 'oliver_setting_font_title_ratio',
										 'type'        => 'range',
										 'input_attrs' => array('min'  => 0.1,
																'max'  => 2,
																'step' => 0.1)));
		
		
		$wp_customize->add_setting('oliver_setting_main_slider_title_text_transform',
								   array('default'           => 'is-slider-title-none-uppercase',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_main_slider_title_text_transform',
								   array('label'    => esc_html__('Slider Title Text Transform', 'oliver'),
										 'section'  => 'oliver_section_featured_area_slider',
										 'settings' => 'oliver_setting_main_slider_title_text_transform',
										 'type'     => 'select',
										 'choices'  => array('is-slider-title-none-uppercase' => 'None',
															 'is-slider-title-uppercase'      => 'Uppercase')));
		
		
		$wp_customize->add_setting('oliver_setting_main_slider_meta_style',
								   array('default'           => 'is-cat-link-borders-light is-cat-link-rounded',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_main_slider_meta_style',
								   array('label'    => esc_html__('Slider Meta Style', 'oliver'),
										 'section'  => 'oliver_section_featured_area_slider',
										 'settings' => 'oliver_setting_main_slider_meta_style',
										 'type'     => 'select',
										 'choices'  => array('is-cat-link-default' 								=> 'Default',
															 'is-cat-link-borders' 								=> 'Borders',
															 'is-cat-link-borders is-cat-link-rounded' 	        => 'Borders Rounded',
															 'is-cat-link-borders-light' 						=> 'Borders Light',
															 'is-cat-link-borders-light is-cat-link-rounded'    => 'Borders Light Rounded',
															 'is-cat-link-solid' 								=> 'Solid',
															 'is-cat-link-solid is-cat-link-rounded' 		    => 'Solid Rounded',
															 'is-cat-link-solid-light' 							=> 'Solid Light',
															 'is-cat-link-solid-light is-cat-link-rounded'      => 'Solid Light Rounded',
															 'is-cat-link-ribbon' 								=> 'Ribbon',
															 'is-cat-link-ribbon-left' 							=> 'Ribbon Left',
															 'is-cat-link-ribbon-right' 						=> 'Ribbon Right',
															 'is-cat-link-ribbon is-cat-link-ribbon-dark' 		=> 'Ribbon Dark',
															 'is-cat-link-ribbon-left is-cat-link-ribbon-dark' 	=> 'Ribbon Dark Left',
															 'is-cat-link-ribbon-right is-cat-link-ribbon-dark' => 'Ribbon Dark Right',
															 'is-cat-link-border-bottom'					    => 'Border Bottom',
															 'is-cat-link-line-before' 							=> 'Line Before',
															 'is-cat-link-dots-bottom' 							=> 'Dots Bottom')));
		
		
		$wp_customize->add_setting('oliver_setting_color_slider_meta_bg_border',
								   array('default'           => "",
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_color_slider_meta_bg_border',
																  array('label'    => esc_html__('Slider Meta Bg/Border Color', 'oliver'),
																		'section'  => 'oliver_section_featured_area_slider',
																		'settings' => 'oliver_setting_color_slider_meta_bg_border')));
		
		
		$wp_customize->add_setting('oliver_setting_main_slider_more_link_visibility',
								   array('default'           => 'is-slider-more-link-show',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_main_slider_more_link_visibility',
								   array('label'    => esc_html__('Slider More Link Visibility', 'oliver'),
										 'section'  => 'oliver_section_featured_area_slider',
										 'settings' => 'oliver_setting_main_slider_more_link_visibility',
										 'type'     => 'select',
										 'choices'  => array('is-slider-more-link-show' 		 => 'Show',
															 'is-slider-more-link-show-on-hover' => 'Show on Hover',
															 'is-slider-more-link-hidden' 		 => 'Hide')));
		
		
		$wp_customize->add_setting('oliver_setting_main_slider_more_link_style',
								   array('default'           => 'is-slider-more-link-border-bottom',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_main_slider_more_link_style',
								   array('label'    => esc_html__('Slider More Link Style', 'oliver'),
										 'section'  => 'oliver_section_featured_area_slider',
										 'settings' => 'oliver_setting_main_slider_more_link_style',
										 'type'     => 'select',
										 'choices'  => array('is-slider-more-link-minimal' 		 => 'Minimal',
															 'is-slider-more-link-button-style'  => 'Button Like',
															 'is-slider-more-link-border-bottom' => 'Border Bottom')));
		
		
		$wp_customize->add_setting('oliver_setting_main_slider_text_align',
								   array('default'           => 'is-slider-text-align-left',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_main_slider_text_align',
								   array('label'    => esc_html__('Slider Text Align', 'oliver'),
										 'section'  => 'oliver_section_featured_area_slider',
										 'settings' => 'oliver_setting_main_slider_text_align',
										 'type'     => 'select',
										 'choices'  => array('is-slider-text-align-center' => 'Center',
															 'is-slider-text-align-left'   => 'Left',
															 'is-slider-text-align-right'  => 'Right')));
		
		
		$wp_customize->add_setting('oliver_setting_main_slider_vertical_align',
								   array('default'           => 'is-slider-v-align-bottom',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_main_slider_vertical_align',
								   array('label'    => esc_html__('Slider Vertical Align', 'oliver'),
										 'section'  => 'oliver_section_featured_area_slider',
										 'settings' => 'oliver_setting_main_slider_vertical_align',
										 'type'     => 'select',
										 'choices'  => array('is-slider-v-align-center' => 'Center',
															 'is-slider-v-align-top'    => 'Top',
															 'is-slider-v-align-bottom' => 'Bottom')));
		
		
		$wp_customize->add_setting('oliver_setting_main_slider_horizontal_align',
								   array('default'           => 'is-slider-h-align-left',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_main_slider_horizontal_align',
								   array('label'    => esc_html__('Slider Horizontal Align', 'oliver'),
										 'section'  => 'oliver_section_featured_area_slider',
										 'settings' => 'oliver_setting_main_slider_horizontal_align',
										 'type'     => 'select',
										 'choices'  => array('is-slider-h-align-center' => 'Center',
															 'is-slider-h-align-left'   => 'Left',
															 'is-slider-h-align-right'  => 'Right')));
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_link_box_title_style',
								   array('default'           => 'is-link-box-title-default',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_link_box_title_style',
								   array('label'    => esc_html__('Link Box Title Style', 'oliver'),
										 'section'  => 'oliver_section_featured_area_link_box',
										 'settings' => 'oliver_setting_link_box_title_style',
										 'type'     => 'select',
										 'choices'  => array('is-link-box-title-default' 						 => 'Default',
															 'is-link-box-title-label' 							 => 'Label',
															 'is-link-box-title-label is-link-box-title-rotated' => 'Label Rotated',
															 'is-link-box-title-inline-borders' 				 => 'Inline Borders',
															 'is-link-box-title-border-bottom' 					 => 'Border Bottom')));
		
		
		$wp_customize->add_setting('oliver_setting_font_link_box_title',
								   array('default'           => 'Coustard',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_link_box_title',
								   array('label'    => esc_html__('Link Box Title Font', 'oliver'),
										 'section'  => 'oliver_section_featured_area_link_box',
										 'settings' => 'oliver_setting_font_link_box_title',
										 'type'     => 'select',
										 'choices'  => $oliver_fonts));
		
		
		$wp_customize->add_setting('oliver_setting_font_weight_link_box_title',
								   array('default'           => '400',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_weight_link_box_title',
								   array('label'    => esc_html__('Link Box Title Font Weight', 'oliver'),
										 'section'  => 'oliver_section_featured_area_link_box',
										 'settings' => 'oliver_setting_font_weight_link_box_title',
										 'type'     => 'select',
										 'choices'  => $oliver_font_weights));
		
		
		$wp_customize->add_setting('oliver_setting_letter_spacing_link_box_title',
								   array('default'           => '0',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_letter_spacing_link_box_title',
								   array('label'       => esc_html__('Link Box Title Letter Spacing (px)', 'oliver'),
										 'section'     => 'oliver_section_featured_area_link_box',
										 'settings'    => 'oliver_setting_letter_spacing_link_box_title',
										 'type'        => 'number',
										 'input_attrs' => array('min'  => -5,
																'max'  => 20,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_font_title_ratio_link_box',
								   array('default'           => '0.5',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_font_title_ratio_link_box',
								   array('label'       => esc_html__('Link Box Title Text Ratio', 'oliver'),
										 'section'     => 'oliver_section_featured_area_link_box',
										 'settings'    => 'oliver_setting_font_title_ratio_link_box',
										 'type'        => 'range',
										 'input_attrs' => array('min'  => 0.1,
																'max'  => 2,
																'step' => 0.05)));
		
		
		$wp_customize->add_setting('oliver_setting_link_box_text_transform',
								   array('default'           => 'is-link-box-title-transform-none',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_link_box_text_transform',
								   array('label'    => esc_html__('Link Box Text Transform', 'oliver'),
										 'section'  => 'oliver_section_featured_area_link_box',
										 'settings' => 'oliver_setting_link_box_text_transform',
										 'type'     => 'select',
										 'choices'  => array('is-link-box-title-transform-none' => 'None',
															 'is-link-box-title-uppercase' 		=> 'Uppercase')));
		
		
		$wp_customize->add_setting('oliver_setting_link_box_text_align',
								   array('default'           => 'is-link-box-text-align-center',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_link_box_text_align',
								   array('label'    => esc_html__('Link Box Text Align', 'oliver'),
										 'section'  => 'oliver_section_featured_area_link_box',
										 'settings' => 'oliver_setting_link_box_text_align',
										 'type'     => 'select',
										 'choices'  => array('is-link-box-text-align-center' => 'Center',
															 'is-link-box-text-align-left' 	 => 'Left',
															 'is-link-box-text-align-right'  => 'Right')));
		
		
		$wp_customize->add_setting('oliver_setting_link_box_vertical_align',
								   array('default'           => 'is-link-box-v-align-center',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_link_box_vertical_align',
								   array('label'    => esc_html__('Link Box Vertical Align', 'oliver'),
										 'section'  => 'oliver_section_featured_area_link_box',
										 'settings' => 'oliver_setting_link_box_vertical_align',
										 'type'     => 'select',
										 'choices'  => array('is-link-box-v-align-center' => 'Center',
															 'is-link-box-v-align-top' 	  => 'Top',
															 'is-link-box-v-align-bottom' => 'Bottom')));
		
		
		$wp_customize->add_setting('oliver_setting_link_box_parallax_effect',
								   array('default'           => 'is-link-box-parallax-no',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_link_box_parallax_effect',
								   array('label'    => esc_html__('Link Box Parallax Effect', 'oliver'),
										 'section'  => 'oliver_section_featured_area_link_box',
										 'settings' => 'oliver_setting_link_box_parallax_effect',
										 'type'     => 'select',
										 'choices'  => array('is-link-box-parallax-no' => 'No',
															 'is-link-box-parallax' => 'Yes')));
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_intro_text_align',
								   array('default'           => 'is-intro-align-center',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_intro_text_align',
								   array('label'    => esc_html__('Intro Text Align', 'oliver'),
										 'section'  => 'oliver_section_featured_area_intro',
										 'settings' => 'oliver_setting_intro_text_align',
										 'type'     => 'select',
										 'choices'  => array('is-intro-align-center' => 'Center',
															 'is-intro-align-left'   => 'Left',
															 'is-intro-align-right'  => 'Right')));
		
		
		$wp_customize->add_setting('oliver_setting_intro_text_color',
								   array('default'           => 'is-intro-text-dark',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_intro_text_color',
								   array('label'    => esc_html__('Intro Text Color', 'oliver'),
										 'section'  => 'oliver_section_featured_area_intro',
										 'settings' => 'oliver_setting_intro_text_color',
										 'type'     => 'select',
										 'choices'  => array('is-intro-text-dark'  => 'Dark',
															 'is-intro-text-light' => 'Light')));
		
		
		$wp_customize->add_setting('oliver_setting_intro_top_bottom_padding',
								   array('default'           => '50',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_intro_top_bottom_padding',
								   array('label'       => esc_html__('Intro Top-Bottom Padding', 'oliver'),
										 'section'     => 'oliver_section_featured_area_intro',
										 'settings'    => 'oliver_setting_intro_top_bottom_padding',
										 'type'        => 'range',
										 'input_attrs' => array('min'  => 20,
																'max'  => 400,
																'step' => 10)));
		
		
		$wp_customize->add_setting('oliver_setting_intro_mask_color',
								   array('default'           => '#25262e',
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_intro_mask_color',
																  array('label'    => esc_html__('Intro Mask Color', 'oliver'),
																		'section'  => 'oliver_section_featured_area_intro',
																		'settings' => 'oliver_setting_intro_mask_color')));
		
		
		$wp_customize->add_setting('oliver_setting_intro_mask_opacity',
								   array('default'           => '0',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_intro_mask_opacity',
								   array('label'       => esc_html__('Intro Mask Opacity', 'oliver'),
										 'section'     => 'oliver_section_featured_area_intro',
										 'settings'    => 'oliver_setting_intro_mask_opacity',
										 'type'        => 'range',
										 'input_attrs' => array('min'  => 0,
																'max'  => 1,
																'step' => 0.1)));
		
		
		$wp_customize->add_setting('oliver_setting_intro_parallax_bg_img',
								   array('default'           => 'is-intro-parallax-no',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_intro_parallax_bg_img',
								   array('label'    => esc_html__('Parallax Background Image', 'oliver'),
										 'section'  => 'oliver_section_featured_area_intro',
										 'settings' => 'oliver_setting_intro_parallax_bg_img',
										 'type'     => 'select',
										 'choices'  => array('is-intro-parallax-no' => 'No',
															 'is-intro-parallax' 	=> 'Yes')));
		
		
		$wp_customize->add_setting('oliver_setting_intro_font_size',
								   array('default'           => '38',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_intro_font_size',
								   array('label'    => esc_html__('Intro Font Size (px)', 'oliver'),
										 'section'  => 'oliver_section_featured_area_intro',
										 'settings' => 'oliver_setting_intro_font_size',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => 9,
																'max'  => 200,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_intro_font',
								   array('default'           => "",
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_intro_font',
								   array('label'    => esc_html__('Intro Font', 'oliver'),
										 'section'  => 'oliver_section_featured_area_intro',
										 'settings' => 'oliver_setting_intro_font',
										 'type'     => 'select',
										 'choices'  => $oliver_fonts));
		
		
		$wp_customize->add_setting('oliver_setting_intro_font_weight',
								   array('default'           => '400',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_intro_font_weight',
								   array('label'    => esc_html__('Intro Font Weight', 'oliver'),
										 'section'  => 'oliver_section_featured_area_intro',
										 'settings' => 'oliver_setting_intro_font_weight',
										 'type'     => 'select',
										 'choices'  => $oliver_font_weights));
		
		
		$wp_customize->add_setting('oliver_setting_intro_letter_spacing',
								   array('default'           => '0',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_intro_letter_spacing',
								   array('label'    => esc_html__('Intro Letter Spacing (px)', 'oliver'),
										 'section'  => 'oliver_section_featured_area_intro',
										 'settings' => 'oliver_setting_intro_letter_spacing',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => -10,
																'max'  => 50,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_intro_text_transform',
								   array('default'           => 'none',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_intro_text_transform',
								   array('label'    => esc_html__('Intro Text Transform', 'oliver'),
										 'section'  => 'oliver_section_featured_area_intro',
										 'settings' => 'oliver_setting_intro_text_transform',
										 'type'     => 'select',
										 'choices'  => array('none' 	 => 'None',
															 'uppercase' => 'Uppercase')));
		
		
		/* ================================================== */
		
		
		$oliver_layouts = array('Regular'         => 'Regular',
									'Grid'            => 'Grid',
									'List'            => 'List',
									'Circles'         => 'Circles',
									'1st Full + Grid' => '1st Full + Grid',
									'1st Full + List' => '1st Full + List');
		
		
		$wp_customize->add_setting('oliver_setting_layout_blog',
								   array('default'           => 'Regular',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_layout_blog',
								   array('label'    => esc_html__('Blog', 'oliver'),
										 'section'  => 'oliver_section_blog',
										 'settings' => 'oliver_setting_layout_blog',
										 'type'     => 'select',
										 'choices'  => $oliver_layouts));
		
		
		$wp_customize->add_setting('oliver_setting_layout_category',
								   array('default'           => 'Grid',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_layout_category',
								   array('label'    => esc_html__('Category Archive', 'oliver'),
										 'section'  => 'oliver_section_blog',
										 'settings' => 'oliver_setting_layout_category',
										 'type'     => 'select',
										 'choices'  => $oliver_layouts));
		
		
		$wp_customize->add_setting('oliver_setting_layout_tag',
								   array('default'           => 'Grid',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_layout_tag',
								   array('label'    => esc_html__('Tag Archive', 'oliver'),
										 'section'  => 'oliver_section_blog',
										 'settings' => 'oliver_setting_layout_tag',
										 'type'     => 'select',
										 'choices'  => $oliver_layouts));
		
		
		$wp_customize->add_setting('oliver_setting_layout_author',
								   array('default'           => 'Grid',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_layout_author',
								   array('label'    => esc_html__('Author Archive', 'oliver'),
										 'section'  => 'oliver_section_blog',
										 'settings' => 'oliver_setting_layout_author',
										 'type'     => 'select',
										 'choices'  => $oliver_layouts));
		
		
		$wp_customize->add_setting('oliver_setting_layout_date',
								   array('default'           => 'Grid',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_layout_date',
								   array('label'    => esc_html__('Date Archive', 'oliver'),
										 'section'  => 'oliver_section_blog',
										 'settings' => 'oliver_setting_layout_date',
										 'type'     => 'select',
										 'choices'  => $oliver_layouts));
		
		
		$wp_customize->add_setting('oliver_setting_layout_search',
								   array('default'           => 'Grid',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_layout_search',
								   array('label'    => esc_html__('Search Result', 'oliver'),
										 'section'  => 'oliver_section_blog',
										 'settings' => 'oliver_setting_layout_search',
										 'type'     => 'select',
										 'choices'  => $oliver_layouts));
		
		
		$wp_customize->add_setting('oliver_setting_blog_text_align',
								   array('default'           => 'is-blog-text-align-center',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_blog_text_align',
								   array('label'    => esc_html__('Blog Text Align', 'oliver'),
										 'section'  => 'oliver_section_blog',
										 'settings' => 'oliver_setting_blog_text_align',
										 'type'     => 'select',
										 'choices'  => array('is-blog-text-align-center' => 'Center',
															 'is-blog-text-align-left'   => 'Left',
															 'is-blog-text-align-right'  => 'Right')));
		
		
		$wp_customize->add_setting('oliver_setting_grid_type',
								   array('default'           => 'masonry',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_grid_type',
								   array('label'    => esc_html__('Grid Type', 'oliver'),
										 'section'  => 'oliver_section_blog',
										 'settings' => 'oliver_setting_grid_type',
										 'type'     => 'select',
										 'choices'  => array('masonry' => 'masonry',
															 'fitRows' => 'fitRows')));
		
		
		$wp_customize->add_setting('oliver_setting_grid_post_width',
								   array('default'           => '320',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_grid_post_width',
								   array('label'    => esc_html__('Grid Post Width (px)', 'oliver'),
										 'section'  => 'oliver_section_blog',
										 'settings' => 'oliver_setting_grid_post_width',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => 120,
																'max'  => 1200,
																'step' => 10)));
		
		
		$wp_customize->add_setting('oliver_setting_sticky_posts',
								   array('default'           => 'include',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_sticky_posts',
								   array('label'    => esc_html__('Sticky Posts', 'oliver'),
										 'section'  => 'oliver_section_blog',
										 'settings' => 'oliver_setting_sticky_posts',
										 'type'     => 'select',
										 'choices'  => array('include' => 'Include to blog',
															 'exclude' => 'Exclude from blog')));
		
		
		$wp_customize->add_setting('oliver_setting_more_link_style',
								   array('default'           => 'is-more-link-border-bottom-dotted',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_more_link_style',
								   array('label'    => esc_html__('More Link Style', 'oliver'),
										 'section'  => 'oliver_section_blog',
										 'settings' => 'oliver_setting_more_link_style',
										 'type'     => 'select',
										 'choices'  => array('is-more-link-button-minimal' 		 => 'Minimal',
															 'is-more-link-button-style' 		 => 'Button Like',
															 'is-more-link-border-bottom' 		 => 'Border Bottom',
															 'is-more-link-border-bottom-light'  => 'Border Bottom Light',
															 'is-more-link-border-bottom-dotted' => 'Border Bottom Dotted')));
		
		
		$wp_customize->add_setting('oliver_setting_automatic_excerpt',
								   array('default'           => 'standard',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_automatic_excerpt',
								   array('label' 	   => esc_html__('Automatic Excerpt', 'oliver'),
										 'description' => esc_html__('Generates an excerpt from the post content.', 'oliver'),
										 'section' 	   => 'oliver_section_blog',
										 'settings'    => 'oliver_setting_automatic_excerpt',
										 'type' 	   => 'select',
										 'choices' 	   => array('standard' => 'Yes - Only for standard format',
																'Yes'      => 'Yes - For all post formats',
																'No'       => 'No')));
		
		
		$wp_customize->add_setting('oliver_setting_excerpt_length',
								   array('default'           => '65',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_excerpt_length',
								   array('label'       => esc_html__('Excerpt Length', 'oliver'),
										 'description' => esc_html__('For regular layout. Default: 65 (words)', 'oliver'),
										 'section'     => 'oliver_section_blog',
										 'settings'    => 'oliver_setting_excerpt_length',
										 'type'        => 'number',
										 'input_attrs' => array('min'  => 20,
																'max'  => 1000,
																'step' => 5)));
		
		
		$wp_customize->add_setting('oliver_setting_excerpt_length_layout_grid',
								   array('default'           => '35',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_excerpt_length_layout_grid',
								   array('label'       => esc_html__('Blog Grid Excerpt Length', 'oliver'),
										 'description' => esc_html__('For grid, list and circles layouts. Default: 35 (words)', 'oliver'),
										 'section'     => 'oliver_section_blog',
										 'settings'    => 'oliver_setting_excerpt_length_layout_grid',
										 'type'        => 'number',
										 'input_attrs' => array('min'  => 20,
																'max'  => 1000,
																'step' => 5)));
		
		
		$wp_customize->add_setting('oliver_setting_font_size_excerpt',
								   array('default'           => '16',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_size_excerpt',
								   array('label'    => esc_html__('Excerpt Font Size (px)', 'oliver'),
										 'section'  => 'oliver_section_blog',
										 'settings' => 'oliver_setting_font_size_excerpt',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => 9,
																'max'  => 200,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_font_size_blog_grid_excerpt',
								   array('default'           => '14',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_size_blog_grid_excerpt',
								   array('label'    => esc_html__('Blog Grid Excerpt Font Size (px)', 'oliver'),
										 'section'  => 'oliver_section_blog',
										 'settings' => 'oliver_setting_font_size_blog_grid_excerpt',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => 9,
																'max'  => 200,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_font_size_blog_regular_post_title',
								   array('default'           => '40',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_size_blog_regular_post_title',
								   array('label'    => esc_html__('Blog Regular Post Title Font Size (px)', 'oliver'),
										 'section'  => 'oliver_section_blog',
										 'settings' => 'oliver_setting_font_size_blog_regular_post_title',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => 9,
																'max'  => 200,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_font_size_blog_grid_post_title',
								   array('default'           => '24',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_size_blog_grid_post_title',
								   array('label'    => esc_html__('Blog Grid Post Title Font Size (px)', 'oliver'),
										 'section'  => 'oliver_section_blog',
										 'settings' => 'oliver_setting_font_size_blog_grid_post_title',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => 9,
																'max'  => 200,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_numbered_pagination',
								   array('default'           => 'No',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_numbered_pagination',
								   array('label'    => esc_html__('Blog Navigation', 'oliver'),
										 'section'  => 'oliver_section_blog',
										 'settings' => 'oliver_setting_numbered_pagination',
										 'type'     => 'select',
										 'choices'  => array('No'  => 'Older/Newer Links',
															 'Yes' => 'Numbered Pagination')));
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_post_style_global',
								   array('default'           => 'post-header-classic',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_post_style_global',
								   array('label'       => esc_html__('Post Style', 'oliver'),
										 'description' => esc_html__('This setting may be overridden for individual articles.', 'oliver'),
										 'section'     => 'oliver_section_post',
										 'settings'    => 'oliver_setting_post_style_global',
										 'type'        => 'select',
										 'choices'     => array('post-header-classic' 						 	  			  => 'Classic',
																'is-top-content-single-medium' 	  						   	  => 'Classic Medium',
																'is-top-content-single-medium with-parallax' 	  			  => 'Classic Medium Parallax',
																'is-top-content-single-full' 		  						  => 'Classic Full',
																'is-top-content-single-full with-parallax' 				   	  => 'Classic Full Parallax',
																'is-top-content-single-full-margins' 						  => 'Classic Full with Margins',
																'is-top-content-single-full-margins with-parallax' 		   	  => 'Classic Full with Margins Parallax',
																'post-header-overlay post-header-overlay-inline is-post-dark' => 'Overlay',
																'is-top-content-single-medium with-overlay' 				  => 'Overlay Medium',
																'is-top-content-single-full with-overlay' 					  => 'Overlay Full',
																'is-top-content-single-full-margins with-overlay' 			  => 'Overlay Full with Margins',
																'is-top-content-single-medium with-title-full' 			   	  => 'Title Full',
																'post-header-classic is-featured-image-left' 				  => 'Image Left',
																'post-header-classic is-featured-image-right' 				  => 'Image Right')));
		
		
		$wp_customize->add_setting('oliver_setting_post_title_style',
								   array('default'           => 'is-single-post-title-default',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_post_title_style',
								   array('label'    => esc_html__('Post Title Style', 'oliver'),
										 'section'  => 'oliver_section_post',
										 'settings' => 'oliver_setting_post_title_style',
										 'type'     => 'select',
										 'choices'  => array('is-single-post-title-default'      => 'Default',
															 'is-single-post-title-with-margins' => 'Post Title With Margins')));
		
		
		$wp_customize->add_setting('oliver_setting_post_featured_image_position',
								   array('default'           => 'below_title',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_post_featured_image_position',
								   array('label'       => esc_html__('Featured Image Position', 'oliver'),
										 'description' => esc_html__('Also for featured videos.', 'oliver'),
										 'section'     => 'oliver_section_post',
										 'settings'    => 'oliver_setting_post_featured_image_position',
										 'type'        => 'select',
										 'choices'     => array('below_title' => 'Below Title',
																'above_title' => 'Above Title')));
		
		
		$wp_customize->add_setting('oliver_setting_post_page_title_text_align',
								   array('default'           => 'is-post-title-align-center',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_post_page_title_text_align',
								   array('label'    => esc_html__('Post-Page Title Text Align', 'oliver'),
										 'section'  => 'oliver_section_post',
										 'settings' => 'oliver_setting_post_page_title_text_align',
										 'type'     => 'select',
										 'choices'  => array('is-post-title-align-center' => 'Center',
															 'is-post-title-align-left'   => 'Left',
															 'is-post-title-align-right'  => 'Right')));
		
		
		$wp_customize->add_setting('oliver_setting_post_media_width',
								   array('default'           => 'is-post-media-fixed',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_post_media_width',
								   array('label'       => esc_html__('Post Media Width', 'oliver'),
										 'description' => esc_html__('For images and embed media like video in content.', 'oliver'),
										 'section'     => 'oliver_section_post',
										 'settings'    => 'oliver_setting_post_media_width',
										 'type'        => 'select',
										 'choices'     => array('is-post-media-fixed'    => 'Fixed',
																'is-post-media-overflow' => 'Overflow')));
		
		
		$wp_customize->add_setting('oliver_setting_share_links',
								   array('default'           => 'Yes',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_share_links',
								   array('label'    => esc_html__('Share Links', 'oliver'),
										 'section'  => 'oliver_section_post',
										 'settings' => 'oliver_setting_share_links',
										 'type'     => 'select',
										 'choices'  => $oliver_setting_yes_no));
		
		
		$wp_customize->add_setting('oliver_setting_post_navigation',
								   array('default'           => 'Yes',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_post_navigation',
								   array('label'       => esc_html__('Post Navigation', 'oliver'),
										 'description' => esc_html__('For previous post/next post.', 'oliver'),
										 'section'     => 'oliver_section_post',
										 'settings'    => 'oliver_setting_post_navigation',
										 'type'        => 'select',
										 'choices'     => $oliver_setting_yes_no));
		
		
		$wp_customize->add_setting('oliver_setting_author_info_box',
								   array('default'           => 'Yes',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_author_info_box',
								   array('label'       => esc_html__('Author Info Box', 'oliver'),
										 'description' => esc_html__('About post author module under post content.', 'oliver'),
										 'section'     => 'oliver_section_post',
										 'settings'    => 'oliver_setting_author_info_box',
										 'type'        => 'select',
										 'choices'     => $oliver_setting_yes_no));
		
		
		$wp_customize->add_setting('oliver_setting_related_posts',
								   array('default'           => 'Yes',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_related_posts',
								   array('label'    => esc_html__('Related Posts', 'oliver'),
										 'section'  => 'oliver_section_post',
										 'settings' => 'oliver_setting_related_posts',
										 'type'     => 'select',
										 'choices'  => $oliver_setting_yes_no));
		
		
		$wp_customize->add_setting('oliver_setting_related_posts_style',
								   array('default'           => 'classic',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_related_posts_style',
								   array('label'    => esc_html__('Related Posts Style', 'oliver'),
										 'section'  => 'oliver_section_post',
										 'settings' => 'oliver_setting_related_posts_style',
										 'type'     => 'select',
										 'choices'  => array('classic' => 'Classic',
															 'overlay' => 'Overlay')));
		
		
		$wp_customize->add_setting('oliver_setting_related_posts_parallax_effect',
								   array('default'           => 'is-related-posts-parallax-no',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_related_posts_parallax_effect',
								   array('label'    => esc_html__('Related Posts Parallax Effect', 'oliver'),
										 'section'  => 'oliver_section_post',
										 'settings' => 'oliver_setting_related_posts_parallax_effect',
										 'type'     => 'select',
										 'choices'  => array('is-related-posts-parallax-no' => 'No',
															 'is-related-posts-parallax' 	=> 'Yes')));
		
		
		$wp_customize->add_setting('oliver_setting_related_posts_width',
								   array('default'           => 'is-related-posts-fixed',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_related_posts_width',
								   array('label'    => esc_html__('Related Posts Width', 'oliver'),
										 'section'  => 'oliver_section_post',
										 'settings' => 'oliver_setting_related_posts_width',
										 'type'     => 'select',
										 'choices'  => array('is-related-posts-fixed'    => 'Fixed',
															 'is-related-posts-overflow' => 'Overflow')));
		
		
		$wp_customize->add_setting('oliver_setting_tags',
								   array('default'           => 'Yes',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_tags',
								   array('label'    => esc_html__('Tags', 'oliver'),
										 'section'  => 'oliver_section_post',
										 'settings' => 'oliver_setting_tags',
										 'type'     => 'select',
										 'choices'  => $oliver_setting_yes_no));
		
		
		$wp_customize->add_setting('oliver_setting_author_info_box_style',
								   array('default'           => 'is-about-author-minimal',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_author_info_box_style',
								   array('label'    => esc_html__('Author Info Box Style', 'oliver'),
										 'section'  => 'oliver_section_post',
										 'settings' => 'oliver_setting_author_info_box_style',
										 'type'     => 'select',
										 'choices'  => array('is-about-author-minimal'      => 'Minimal',
															 'is-about-author-boxed'        => 'Boxed',
															 'is-about-author-boxed-dark'   => 'Boxed Dark',
															 'is-about-author-border'       => 'Border',
															 'is-about-author-border-arrow' => 'Border Arrow')));
		
		
		$wp_customize->add_setting('oliver_setting_share_links_style',
								   array('default'           => 'is-share-links-minimal',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_share_links_style',
								   array('label'    => esc_html__('Share Links Style', 'oliver'),
										 'section'  => 'oliver_section_post',
										 'settings' => 'oliver_setting_share_links_style',
										 'type'     => 'select',
										 'choices'  => array('is-share-links-minimal' => 'Minimal',
															 'is-share-links-boxed'   => 'Boxed',
															 'is-share-links-border'  => 'Border')));
		
		
		$wp_customize->add_setting('oliver_setting_tag_cloud_style',
								   array('default'           => 'is-tagcloud-minimal',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_tag_cloud_style',
								   array('label'    => esc_html__('Tag Cloud Style', 'oliver'),
										 'section'  => 'oliver_section_post',
										 'settings' => 'oliver_setting_tag_cloud_style',
										 'type'     => 'select',
										 'choices'  => array('is-tagcloud-minimal' => 'Minimal',
															 'is-tagcloud-solid'   => 'Solid')));
		
		
		$wp_customize->add_setting('oliver_setting_post_nav_image',
								   array('default'           => 'is-nav-single-rounded',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_post_nav_image',
								   array('label'    => esc_html__('Post Navigation Image', 'oliver'),
										 'section'  => 'oliver_section_post',
										 'settings' => 'oliver_setting_post_nav_image',
										 'type'     => 'select',
										 'choices'  => array('is-nav-single-rounded' => 'Rounded',
															 'is-nav-single-square'  => 'Square')));
		
		
		$wp_customize->add_setting('oliver_setting_post_nav_animated',
								   array('default'           => 'is-nav-single-no-animated',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_post_nav_animated',
								   array('label'    => esc_html__('Post Navigation Animated', 'oliver'),
										 'section'  => 'oliver_section_post',
										 'settings' => 'oliver_setting_post_nav_animated',
										 'type'     => 'select',
										 'choices'  => array('is-nav-single-no-animated' => 'No',
															 'is-nav-single-animated'    => 'Yes')));
		
		
		$wp_customize->add_setting('oliver_setting_comments_style',
								   array('default'           => 'is-comments-minimal',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_comments_style',
								   array('label'    => esc_html__('Comments Style', 'oliver'),
										 'section'  => 'oliver_section_post',
										 'settings' => 'oliver_setting_comments_style',
										 'type'     => 'select',
										 'choices'  => array('is-comments-minimal'                                             => 'Minimal',
															 'is-comments-boxed is-comments-boxed-solid'                       => 'Boxed',
															 'is-comments-boxed is-comments-border'                            => 'Border',
															 'is-comments-boxed is-comments-boxed-solid is-comments-image-out' => 'Boxed Image Out',
															 'is-comments-boxed is-comments-border is-comments-image-out'      => 'Border Image Out')));
		
		
		$wp_customize->add_setting('oliver_setting_comment_image_shape',
								   array('default'           => 'is-comments-image-rounded',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_comment_image_shape',
								   array('label'    => esc_html__('Comment Image Shape', 'oliver'),
										 'section'  => 'oliver_section_post',
										 'settings' => 'oliver_setting_comment_image_shape',
										 'type'     => 'select',
										 'choices'  => array('is-comments-image-rounded'      => 'Circle',
															 'is-comments-image-soft-rounded' => 'Soft Rounded',
															 'is-comments-image-square'       => 'Square')));
		
		
		$wp_customize->add_setting('oliver_setting_comment_form_style',
								   array('default'           => 'is-comment-form-minimal',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_comment_form_style',
								   array('label'    => esc_html__('Comment Form Style', 'oliver'),
										 'section'  => 'oliver_section_post',
										 'settings' => 'oliver_setting_comment_form_style',
										 'type'     => 'select',
										 'choices'  => array('is-comment-form-minimal'                            => 'Minimal',
															 'is-comment-form-boxed is-comment-form-boxed-solid'  => 'Boxed',
															 'is-comment-form-boxed is-comment-form-border'       => 'Border',
															 'is-comment-form-boxed is-comment-form-border-arrow' => 'Border Arrow')));
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_meta_prefix_style',
								   array('default'           => 'is-meta-with-none',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_meta_prefix_style',
								   array('label'    => esc_html__('Meta Prefix Style', 'oliver'),
										 'section'  => 'oliver_section_meta_style',
										 'settings' => 'oliver_setting_meta_prefix_style',
										 'type'     => 'select',
										 'choices'  => array('is-meta-with-none'   => 'None',
															 'is-meta-with-icons'  => 'Icons',
															 'is-meta-with-prefix' => 'Prefix Text')));
		
		
		$wp_customize->add_setting('oliver_setting_meta_cat_link_style',
								   array('default'           => 'is-cat-link-borders-light is-cat-link-rounded',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_meta_cat_link_style',
								   array('label'    => esc_html__('Category Link Style', 'oliver'),
										 'section'  => 'oliver_section_meta_style',
										 'settings' => 'oliver_setting_meta_cat_link_style',
										 'type'     => 'select',
										 'choices'  => array('is-cat-link-link-style' 						  	=> 'Link Style',
															 'is-cat-link-regular' 							  	=> 'Regular Text',
															 'is-cat-link-border-bottom' 					  	=> 'Border Bottom',
															 'is-cat-link-borders' 							  	=> 'Borders',
															 'is-cat-link-borders is-cat-link-rounded' 		  	=> 'Borders Round',
															 'is-cat-link-borders-light' 					  	=> 'Borders Light',
															 'is-cat-link-borders-light is-cat-link-rounded'  	=> 'Borders Light Round',
															 'is-cat-link-solid' 							  	=> 'Solid',
															 'is-cat-link-solid is-cat-link-rounded' 		  	=> 'Solid Round',
															 'is-cat-link-solid-light' 						  	=> 'Solid Light',
															 'is-cat-link-solid-light is-cat-link-rounded' 	  	=> 'Solid Light Round',
															 'is-cat-link-underline' 						  	=> 'Underline',
															 'is-cat-link-line-before' 						  	=> 'Line Before',
															 'is-cat-link-ribbon' 						  	  	=> 'Ribbon',
															 'is-cat-link-ribbon-left' 						  	=> 'Ribbon Left',
															 'is-cat-link-ribbon-right' 					  	=> 'Ribbon Right',
															 'is-cat-link-ribbon is-cat-link-ribbon-dark' 	  	=> 'Ribbon Dark',
															 'is-cat-link-ribbon-left is-cat-link-ribbon-dark'  => 'Ribbon Dark Left',
															 'is-cat-link-ribbon-right is-cat-link-ribbon-dark' => 'Ribbon Dark Right')));
		
		
		$wp_customize->add_setting('oliver_setting_font_size_meta',
								   array('default'           => '12',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control('oliver_control_font_size_meta',
								   array('label'    => esc_html__('Meta Font Size (px)', 'oliver'),
										 'section'  => 'oliver_section_meta_style',
										 'settings' => 'oliver_setting_font_size_meta',
										 'type'     => 'number',
										 'input_attrs' => array('min'  => 8,
																'max'  => 24,
																'step' => 1)));
		
		
		$wp_customize->add_setting('oliver_setting_color_cat_link_bg_border',
								   array('default'           => "",
										 'sanitize_callback' => 'sanitize_hex_color',
										 'transport'         => 'postMessage'));
		
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,
																  'oliver_control_color_cat_link_bg_border',
																  array('label'    => esc_html__('Category Link Bg/Border Color', 'oliver'),
																		'section'  => 'oliver_section_meta_style',
																		'settings' => 'oliver_setting_color_cat_link_bg_border')));
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_meta_blog_cat',
								   array('default'           => 'below_title',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_meta_blog_cat',
								   array('label'    => esc_html__('Category', 'oliver'),
										 'section'  => 'oliver_section_meta_blog',
										 'settings' => 'oliver_setting_meta_blog_cat',
										 'type'     => 'select',
										 'choices'  => array('above_title'   => 'Above Title',
															 'below_title'   => 'Below Title',
															 'below_content' => 'Below Content',
															 'hidden' 		 => 'Hidden')));
		
		
		$wp_customize->add_setting('oliver_setting_meta_blog_date',
								   array('default'           => 'below_title',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_meta_blog_date',
								   array('label'    => esc_html__('Date', 'oliver'),
										 'section'  => 'oliver_section_meta_blog',
										 'settings' => 'oliver_setting_meta_blog_date',
										 'type'     => 'select',
										 'choices'  => array('above_title'   => 'Above Title',
															 'below_title'   => 'Below Title',
															 'below_content' => 'Below Content',
															 'hidden' 		 => 'Hidden')));
		
		
		$wp_customize->add_setting('oliver_setting_meta_blog_comment',
								   array('default'           => 'hidden',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_meta_blog_comment',
								   array('label'    => esc_html__('Comment', 'oliver'),
										 'section'  => 'oliver_section_meta_blog',
										 'settings' => 'oliver_setting_meta_blog_comment',
										 'type'     => 'select',
										 'choices'  => array('above_title'   => 'Above Title',
															 'below_title'   => 'Below Title',
															 'below_content' => 'Below Content',
															 'hidden' 		 => 'Hidden')));
		
		
		$wp_customize->add_setting('oliver_setting_meta_blog_comment_hide_0',
								   array('default'   		 => 1,
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport' 		 => 'refresh'));
		
		$wp_customize->add_control('oliver_control_meta_blog_comment_hide_0',
								   array('label'    => esc_html__('Hide Comment if count is 0', 'oliver'),
										 'section'  => 'oliver_section_meta_blog',
										 'settings' => 'oliver_setting_meta_blog_comment_hide_0',
										 'type'     => 'checkbox'));
		
		
		$wp_customize->add_setting('oliver_setting_meta_blog_author',
								   array('default'           => 'hidden',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_meta_blog_author',
								   array('label'    => esc_html__('Author', 'oliver'),
										 'section'  => 'oliver_section_meta_blog',
										 'settings' => 'oliver_setting_meta_blog_author',
										 'type'     => 'select',
										 'choices'  => array('above_title'   => 'Above Title',
															 'below_title'   => 'Below Title',
															 'below_content' => 'Below Content',
															 'hidden' 		 => 'Hidden')));
		
		
		$wp_customize->add_setting('oliver_setting_meta_blog_share',
								   array('default'           => 'below_title',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_meta_blog_share',
								   array('label'    => esc_html__('Share', 'oliver'),
										 'section'  => 'oliver_section_meta_blog',
										 'settings' => 'oliver_setting_meta_blog_share',
										 'type'     => 'select',
										 'choices'  => array('above_title'   => 'Above Title',
															 'below_title'   => 'Below Title',
															 'below_content' => 'Below Content',
															 'hidden' 		 => 'Hidden')));
		
		
		$wp_customize->add_setting('oliver_setting_meta_blog_like',
								   array('default'           => 'below_title',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_meta_blog_like',
								   array('label'       => esc_html__('Like', 'oliver'),
										 'description' => esc_html__('Install and activate "I Recommend This" plugin from Appearance > Install Plugins.', 'oliver'),
										 'section'     => 'oliver_section_meta_blog',
										 'settings'    => 'oliver_setting_meta_blog_like',
										 'type'        => 'select',
										 'choices'     => array('above_title'   => 'Above Title',
																'below_title'   => 'Below Title',
																'below_content' => 'Below Content',
																'hidden' 		=> 'Hidden')));
		
		
		$wp_customize->add_setting('oliver_setting_meta_blog_edit',
								   array('default'           => 'hidden',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_meta_blog_edit',
								   array('label'    => esc_html__('Edit', 'oliver'),
										 'section'  => 'oliver_section_meta_blog',
										 'settings' => 'oliver_setting_meta_blog_edit',
										 'type'     => 'select',
										 'choices'  => array('above_title'   => 'Above Title',
															 'below_title'   => 'Below Title',
															 'below_content' => 'Below Content',
															 'hidden' 		 => 'Hidden')));
		
		
		/* ================================================== */
		
		
		$wp_customize->add_setting('oliver_setting_meta_post_cat',
								   array('default'           => 'below_title',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_meta_post_cat',
								   array('label'    => esc_html__('Category', 'oliver'),
										 'section'  => 'oliver_section_meta_post',
										 'settings' => 'oliver_setting_meta_post_cat',
										 'type'     => 'select',
										 'choices'  => array('above_title'   => 'Above Title',
															 'below_title'   => 'Below Title',
															 'below_content' => 'Below Content',
															 'hidden' 		 => 'Hidden')));
		
		
		$wp_customize->add_setting('oliver_setting_meta_post_date',
								   array('default'           => 'below_title',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_meta_post_date',
								   array('label'    => esc_html__('Date', 'oliver'),
										 'section'  => 'oliver_section_meta_post',
										 'settings' => 'oliver_setting_meta_post_date',
										 'type'     => 'select',
										 'choices'  => array('above_title'   => 'Above Title',
															 'below_title'   => 'Below Title',
															 'below_content' => 'Below Content',
															 'hidden' 		 => 'Hidden')));
		
		
		$wp_customize->add_setting('oliver_setting_meta_post_comment',
								   array('default'           => 'below_title',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_meta_post_comment',
								   array('label'    => esc_html__('Comment', 'oliver'),
										 'section'  => 'oliver_section_meta_post',
										 'settings' => 'oliver_setting_meta_post_comment',
										 'type'     => 'select',
										 'choices'  => array('above_title'   => 'Above Title',
															 'below_title'   => 'Below Title',
															 'below_content' => 'Below Content',
															 'hidden' 		 => 'Hidden')));
		
		
		$wp_customize->add_setting('oliver_setting_meta_post_comment_hide_0',
								   array('default'   		 => 1,
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport' 		 => 'refresh'));
		
		$wp_customize->add_control('oliver_control_meta_post_comment_hide_0',
								   array('label'    => esc_html__('Hide Comment if count is 0', 'oliver'),
										 'section'  => 'oliver_section_meta_post',
										 'settings' => 'oliver_setting_meta_post_comment_hide_0',
										 'type'     => 'checkbox'));
		
		
		$wp_customize->add_setting('oliver_setting_meta_post_author',
								   array('default'           => 'hidden',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_meta_post_author',
								   array('label'    => esc_html__('Author', 'oliver'),
										 'section'  => 'oliver_section_meta_post',
										 'settings' => 'oliver_setting_meta_post_author',
										 'type'     => 'select',
										 'choices'  => array('above_title'   => 'Above Title',
															 'below_title'   => 'Below Title',
															 'below_content' => 'Below Content',
															 'hidden' 		 => 'Hidden')));
		
		
		$wp_customize->add_setting('oliver_setting_meta_post_share',
								   array('default'           => 'below_title',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_meta_post_share',
								   array('label'    => esc_html__('Share', 'oliver'),
										 'section'  => 'oliver_section_meta_post',
										 'settings' => 'oliver_setting_meta_post_share',
										 'type'     => 'select',
										 'choices'  => array('above_title'   => 'Above Title',
															 'below_title'   => 'Below Title',
															 'below_content' => 'Below Content',
															 'hidden' 		 => 'Hidden')));
		
		
		$wp_customize->add_setting('oliver_setting_meta_post_like',
								   array('default'           => 'below_title',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_meta_post_like',
								   array('label'       => esc_html__('Like', 'oliver'),
										 'description' => esc_html__('Install and activate "I Recommend This" plugin from Appearance > Install Plugins.', 'oliver'),
										 'section'     => 'oliver_section_meta_post',
										 'settings'    => 'oliver_setting_meta_post_like',
										 'type'        => 'select',
										 'choices'     => array('above_title'   => 'Above Title',
																'below_title'   => 'Below Title',
																'below_content' => 'Below Content',
																'hidden' 		=> 'Hidden')));
		
		
		$wp_customize->add_setting('oliver_setting_meta_post_edit',
								   array('default'           => 'hidden',
										 'sanitize_callback' => 'oliver_sanitize',
										 'transport'         => 'refresh'));
		
		$wp_customize->add_control('oliver_control_meta_post_edit',
								   array('label'    => esc_html__('Edit', 'oliver'),
										 'section'  => 'oliver_section_meta_post',
										 'settings' => 'oliver_setting_meta_post_edit',
										 'type'     => 'select',
										 'choices'  => array('above_title'   => 'Above Title',
															 'below_title'   => 'Below Title',
															 'below_content' => 'Below Content',
															 'hidden' 		 => 'Hidden')));
		
		
		/* ================================================== */
		
		
		$wp_customize->get_setting('blogname')->transport 		 = 'postMessage';
		$wp_customize->get_setting('blogdescription')->transport = 'postMessage';
	}
	
	add_action('customize_register', 'oliver_customize_register');
	
	
	function oliver_sanitize($value)
	{
		return $value;
	}


/* ============================================================================================================================================= */


	if (! function_exists('oliver_portfolio_page__post_class'))
	{
		function oliver_portfolio_page__post_class()
		{
			$taxonomy         = 'portfolio-category';
			$categories_slugs = "";
			$categories 	  = get_the_terms(get_the_ID(), $taxonomy);
			
			if ($categories && (! is_wp_error($categories)))
			{
				foreach ($categories as $category)
				{
					// Get post's category slug and its parent category slug.
					
					$categories_slugs .= get_term_parents_list(
						$category->term_id,
						$taxonomy,
						array(
							'format'    => 'slug',
							'separator' => ' ',
							'link'      => false,
							'inclusive' => true,
						)
					);
				}
			}
			
			$post_class = esc_attr($categories_slugs);
			
			return $post_class;
		}
	}


/* ============================================================================================================================================= */


	if (is_admin())
	{
		include_once(get_template_directory() . '/admin/theme-options.php');
	}


/* ============================================================================================================================================= */


	// TGM Plugin Activation.
	
	require_once get_template_directory() . '/admin/class-tgm-plugin-activation.php';
	
	
	function oliver_plugins()
	{
		$message = "";
		
		if (isset($_GET['plugin']))
		{
			if ($_GET['plugin'] == 'one-click-demo-import')
			{
				// Plugin activated.
				
				$message .= '<div class="notice notice-info pixelwars-tgmpa-notice">';
				$message .= 	'<h3>' . esc_html__('One Click Demo Import', 'oliver') . ' </h3>';
				$message .= 	'<p>' . esc_html__('Importing demo data is the quickest and easiest way to set up your new theme.', 'oliver') . ' </p>';
				$message .= 	'<p><a class="button button-primary" href="' . esc_url(admin_url('themes.php?page=one-click-demo-import')) . '">' . esc_html__('Run Importer', 'oliver') . '</a></p>';
				$message .= '</div>';
			}
		}
		else
		{
			$message .= '<div class="notice notice-warning pixelwars-tgmpa-notice">';
			$message .= 	'<h3>' . esc_html__('Important', 'oliver') . ' </h3>';
			$message .= 	'<p>' . esc_html__('Install/Activate ', 'oliver') . ' <b><u>' . esc_html__('One Click Demo Import', 'oliver') . '</u></b> ' . esc_html__('plugin to import theme demo.', 'oliver') . '</p>';
			$message .= '</div>';
		}
		
		$config = array(
			'id'           => 'oliver_tgmpa',
			'default_path' => "",
			'menu'         => 'oliver-install-update-theme-plugins',
			'parent_slug'  => 'themes.php',
			'capability'   => 'edit_theme_options',
			'is_automatic' => true,
			'has_notices'  => false,
			'dismissable'  => true,
			'dismiss_msg'  => '<h2>' . esc_html__('Theme Plugins', 'oliver') . '</h2>',
			'message'      => $message,
			'strings'      => array(
				'menu_title' => esc_html__('Install Theme Plugins',        'oliver'),
				'page_title' => esc_html__('Install/Update Theme Plugins', 'oliver'),
			)
		);
		
		$plugins = array(
			array(
				'name'               => esc_html__('Oliver Shortcodes', 'oliver'),
				'slug'               => 'oliver-shortcodes',
				'source'             => get_template_directory() . '/admin/plugins/oliver-shortcodes.zip',
				'version'            => '1.0.1',
				'required'           => false,
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => "",
				'is_callable'        => ""
			),
			array(
				'name'               => esc_html__('Pixelwars Core', 'oliver'),
				'slug'               => 'pixelwars-core',
				'source'             => get_template_directory() . '/admin/plugins/pixelwars-core.zip',
				'version'            => '1.3.0',
				'required'           => false,
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => "",
				'is_callable'        => ""
			),
			array(
				'name'               => esc_html__('WPBakery Page Builder', 'oliver'),
				'slug'               => 'js_composer',
				'source'             => get_template_directory() . '/admin/plugins/js_composer.zip',
				'version'            => '7.5',
				'required'           => false,
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => "",
				'is_callable'        => ""
			),
			array(
				'name'               => esc_html__('I Recommend This', 'oliver'),
				'slug'               => 'i-recommend-this',
				'source'             => get_template_directory() . '/admin/plugins/i-recommend-this.zip',
				'version'            => '3.9.0',
				'required'           => false,
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => "",
				'is_callable'        => ""
			),
			array(
				'name'     => esc_html__('Livemesh Addons for WPBakery Page Builder', 'oliver'),
				'slug'     => 'addons-for-visual-composer',
				'required' => false
			),
			array(
				'name'     => esc_html__('One Click Demo Import', 'oliver'),
				'slug'     => 'one-click-demo-import',
				'required' => false
			),
			array(
				'name'     => esc_html__('Regenerate Thumbnails', 'oliver'),
				'slug'     => 'regenerate-thumbnails',
				'required' => false
			),
			array(
				'name'     => esc_html__('Loco Translate', 'oliver'),
				'slug'     => 'loco-translate',
				'required' => false
			),
			array(
				'name'     => esc_html__('Instagram Feed Gallery', 'oliver'),
				'slug'     => 'insta-gallery',
				'required' => false
			),
			array(
				'name'     => esc_html__('Top 10 - Popular Posts', 'oliver'),
				'slug'     => 'top-10',
				'required' => false
			),
			array(
				'name'     => esc_html__('MailChimp for WordPress', 'oliver'),
				'slug'     => 'mailchimp-for-wp',
				'required' => false
			),
			array(
				'name'     => esc_html__('Selection Sharer', 'oliver'),
				'slug'     => 'selection-sharer',
				'required' => false
			),
			array(
				'name'     => esc_html__('WPFront Scroll Top', 'oliver'),
				'slug'     => 'wpfront-scroll-top',
				'required' => false
			),
			array(
				'name'     => esc_html__('SVG Support', 'oliver'),
				'slug'     => 'svg-support',
				'required' => false
			),
			array(
				'name'     => esc_html__('WooCommerce', 'oliver'),
				'slug'     => 'woocommerce',
				'required' => false
			)
		);
		
		tgmpa($plugins, $config);
	}
	
	add_action('tgmpa_register', 'oliver_plugins');


/* ============================================================================================================================================= */


	function oliver_vc_theme_default()
	{
		$list = array(
			'page',
			'post',
			'portfolio'
		);
		
		vc_set_default_editor_post_types($list);
		
		vc_set_as_theme();
	}
	
	add_action('vc_before_init', 'oliver_vc_theme_default');


/* ============================================================================================================================================= */


	include_once(get_template_directory() . '/admin/customizer-inline-style.php');
	include_once(get_template_directory() . '/admin/functions-core.php');
	include_once(get_template_directory() . '/admin/functions-header.php');
	include_once(get_template_directory() . '/admin/functions-footer.php');
	include_once(get_template_directory() . '/admin/functions-portfolio.php');
	include_once(get_template_directory() . '/admin/widgets.php');


/* ============================================================================================================================================= */


	add_filter('pt-ocdi/regenerate_thumbnails_in_content_import', '__return_false');
	
	
	function oliver_ocdi_time_for_one_ajax_call()
	{
		return 10;
	}
	
	add_action('pt-ocdi/time_for_one_ajax_call', 'oliver_ocdi_time_for_one_ajax_call');
	
	
	function oliver_ocdi_after_import()
	{
		// Assign menus to their locations.
		
		$main_menu = get_term_by('name', 'Custom Menu', 'nav_menu');
		
		set_theme_mod(
			'nav_menu_locations',
			array(
				'oliver_theme_menu_location' => $main_menu->term_id,
			)
		);
		
		// Assign Homepage and Blog page.
		
		$homepage  = get_page_by_title('Home'); // Get homepage.
		$blog_page = get_page_by_title('Blog'); // Get blog page.
		
		update_option('show_on_front',  'page');
		update_option('page_on_front',  $homepage->ID);  // Set homepage.
		update_option('page_for_posts', $blog_page->ID); // Set blog page.
	}
	
	add_action('ocdi/after_import', 'oliver_ocdi_after_import');
	
	
	function oliver_ocdi_import_files()
	{
		$theme_directory     = trailingslashit(get_template_directory());
		$theme_directory_url = trailingslashit(get_template_directory_uri());
		
		return array(
			array(
				'import_file_name'         => esc_html__('Demo Content', 'oliver'),
				'local_import_file'        => $theme_directory     . 'admin/demo-data/content.xml',
				'local_import_widget_file' => $theme_directory     . 'admin/demo-data/widgets.wie',
				'import_preview_image_url' => $theme_directory_url . 'admin/demo-data/screenshot.jpg',
				'preview_url'              => 'https://themes.pixelwars.org/oliver/'
				
			),
			array(
				'import_file_name'         => esc_html__('Theme Demo Helper', 'oliver'),
				'local_import_file'        => $theme_directory     . 'admin/demo-data/content.xml',
				'local_import_widget_file' => $theme_directory     . 'admin/demo-data/widgets.wie',
				'import_preview_image_url' => $theme_directory_url . 'admin/demo-data/screenshot.jpg',
				'preview_url'              => 'https://themes.pixelwars.org/oliver/'
				
			)
		);
	}
	
	add_filter('pt-ocdi/import_files', 'oliver_ocdi_import_files');

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328587&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        